@@ -1,8 +1,8 @@
 /*
  *   cda - Command-line CD Audio Player
  *
- *   Copyright (C) 1993-2000  Ti Kan
- *   E-mail: ti@amb.org
+ *   Copyright (C) 1993-2002  Ti Kan
+ *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 #define __CDA_H__
 
 #ifndef LINT
-static char *_cda_h_ident_ = "@(#)cda.h	6.22 00/01/16";
+static char *_cda_h_ident_ = "@(#)cda.h	6.32 02/03/27";
 #endif
 
 
@@ -63,12 +63,20 @@ static char *_cda_h_ident_ = "@(#)cda.h	6.22 00/01/16";
 #define CDA_VERSION		0x113
 #define CDA_DEBUG		0x114
 #define CDA_TOC2		0x115
-#define CDA_SETQUERYID		0x116
-#define CDA_ON_LOAD		0x117
-#define CDA_ON_EXIT		0x118
-#define CDA_ON_DONE		0x119
-#define CDA_ON_EJECT		0x11a
-#define CDA_CHGR		0x11b
+#define CDA_ON_LOAD		0x116
+#define CDA_ON_EXIT		0x117
+#define CDA_ON_DONE		0x118
+#define CDA_ON_EJECT		0x119
+#define CDA_CHGR		0x11a
+#define CDA_NOTES		0x11b
+#define CDA_CDDBREG		0x11c
+#define CDA_CDDBHINT		0x11d
+#define CDA_MODE		0x11e
+#define CDA_JITTER		0x11f
+#define CDA_TRKFILE		0x120
+#define CDA_FILEFMT		0x121
+#define CDA_FILE		0x122
+#define CDA_PIPEPROG		0x123
 
 
 
@@ -155,6 +163,7 @@ typedef struct cda_pkt {
 
 
 /* Public function prototypes */
+extern void		cda_echo(FILE *, bool_t);
 extern curstat_t	*curstat_addr(void);
 extern void		cda_quit(curstat_t *);
 extern void		cda_warning_msg(char *, char *);
@@ -163,7 +172,7 @@ extern void		cda_parse_devlist(curstat_t *);
 extern void		cda_hist_init(curstat_t *);
 extern void		cda_hist_new(curstat_t *);
 extern void		cda_dbclear(curstat_t *, bool_t);
-extern bool_t		cda_dbload(word32_t, int (*)(cddb_match_t *),
+extern bool_t		cda_dbload(word32_t, int (*)(cdinfo_match_t *),
 				   int (*)(int), int);
 extern bool_t		cda_sendcmd(word32_t, word32_t [], int *);
 extern bool_t		cda_daemon_alive(void);
