@@ -1,7 +1,7 @@
 /*
  *   cda - Command-line CD Audio Player
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,7 @@
  */
 
 #ifndef LINT
-static char *_visual_c_ident_ = "@(#)visual.c	6.91 01/07/24";
+static char *_visual_c_ident_ = "@(#)visual.c	6.93 02/04/09";
 #endif
 
 #ifndef NOVISUAL
@@ -84,15 +84,15 @@ STATIC int		scroll_line,		/* 1st line of info window */
 			old_route = 1,
 			track = -2,		/* Current track no. */
 			savch;			/* Saved char for cda_ungetch */
-STATIC bool_t		isvisual,		/* Currently in visual mode */
-			stat_on,		/* Visual: cda is "on" */
+STATIC bool_t		isvisual = FALSE,	/* Currently in visual mode */
+			stat_on = FALSE,	/* Visual: cda is "on" */
 			ostat_on = TRUE,	/* Previous value */
 			refresh_fkeys = TRUE,	/* Refresh funct key labels */
-			help,			/* Display help in info_win? */
+			help = FALSE,		/* Display help in info_win? */
 			old_help = TRUE,	/* Previous value */
-			refresh_sts,		/* Refresh status line */
-			echflag,		/* Own echo flag */
-			savch_echo,		/* Control echo for savch */
+			refresh_sts = FALSE,	/* Refresh status line */
+			echflag = FALSE,	/* Own echo flag */
+			savch_echo = FALSE,	/* Control echo for savch */
 			loaddb = TRUE;		/* Load CD information */
 STATIC word32_t		oastat0 = (word32_t)-1,	/* Previous status value */
 			oastat1 = (word32_t)-1;
