@@ -4,7 +4,7 @@
  *	This library implements an interface to access the "classic"
  *	CDDB1 services.
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
  *
  */
 #ifndef LINT
-static char     *_fcddb_c_ident_ = "@(#)fcddb.c	1.53 01/07/26";
+static char     *_fcddb_c_ident_ = "@(#)fcddb.c	1.56 02/04/24";
 #endif
 
 #include "fcddb.h"
@@ -48,6 +48,7 @@ static char     *_fcddb_c_ident_ = "@(#)fcddb.c	1.53 01/07/26";
 #define DIR_BEG			'/'		/* Directory start */
 #define DIR_SEP			'/'		/* Directory separator */
 #define DIR_END			'/'		/* Directory end */
+#define CUR_DIR			"."		/* Current directory */
 
 /* Defines used by fcddb_runcmd */
 #define STR_SHPATH		"/bin/sh"	/* Path to shell */
@@ -69,6 +70,7 @@ static char     *_fcddb_c_ident_ = "@(#)fcddb.c	1.53 01/07/26";
 #define DIR_BEG			'['		/* Directory start */
 #define DIR_SEP			'.'		/* Directory separator */
 #define DIR_END			']'		/* Directory end */
+#define CUR_DIR			"[]"		/* Current directory */
 
 #endif	/* __VMS */
 
@@ -1256,7 +1258,7 @@ fcddb_parse_cddb_data(
 
 			(void) fcddb_strcat(dp->fullname.name, p);
 		}
-		else if (sscanf(p, "TTITLE%u=", &n) > 0) {
+		else if (sscanf(p, "TTITLE%d=", &n) > 0) {
 			/* Track title */
 			p = strchr(p, '=');
 			p++;
@@ -1319,7 +1321,7 @@ fcddb_parse_cddb_data(
 
 			(void) fcddb_strcat(dp->notes, p);
 		}
-		else if (sscanf(p, "EXTT%u=", &n) > 0) {
+		else if (sscanf(p, "EXTT%d=", &n) > 0) {
 			/* Track notes */
 			p = strchr(p, '=');
 			p++;
@@ -2903,7 +2905,7 @@ fcddb_homedir(void)
 	/* If we still can't get the home directory, just set it to the
 	 * current directory (shrug).
 	 */
-	return (".");
+	return (CUR_DIR);
 #else
 	char		*cp;
 	static char	buf[FILE_PATH_SZ];
