@@ -1,7 +1,7 @@
 /*
  *   cdinfo - CD Information Management Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  *
  */
 #ifndef LINT
-static char *_cdinfo_x_c_ident_ = "@(#)cdinfo_x.c	7.120 01/07/26";
+static char *_cdinfo_x_c_ident_ = "@(#)cdinfo_x.c	7.128 02/05/04";
 #endif
 
 #ifdef __VMS
@@ -44,6 +44,7 @@ extern cdinfo_client_t	*cdinfo_clinfo;		/* Client info */
 extern cdinfo_cddb_t	*cdinfo_cddbp;		/* Opened CDDB handle */
 extern w_ent_t		*cdinfo_discog,		/* Local discog menu ptr */
 			*cdinfo_scddb;		/* Search CDDB menu ptr */
+extern void		*cdinfo_lconv_desc;	/* Charset conv descriptor */
 extern bool_t		ischild;		/* Is a child process */
 
 STATIC pid_t		child_pid = 0;		/* Child pid */
@@ -324,6 +325,7 @@ cdinfo_txtreduce(char *text, bool_t reduce)
  *	Make a URL string from a template.
  *
  * Args:
+ *	s - Pointer to the curstat_t structure
  *	tmpl - Template string
  *	url - Buffer to store resultant URL string
  *	trkpos - The track position for %T or %t
@@ -332,7 +334,7 @@ cdinfo_txtreduce(char *text, bool_t reduce)
  *	Nothing.
  */
 void
-cdinfo_tmpl_to_url(char *tmpl, char *url, int trkpos)
+cdinfo_tmpl_to_url(curstat_t *s, char *tmpl, char *url, int trkpos)
 {
 	char	*q,
 		*r,
@@ -388,6 +390,9 @@ cdinfo_tmpl_to_url(char *tmpl, char *url, int trkpos)
 				/* Translate disk artist into a
 				 * keyword string in CGI form
 				 */
+				if (cdinfo_db.disc.artist == NULL)
+					break;
+
 				q = cdinfo_txtreduce(
 					cdinfo_db.disc.artist,
 					(bool_t) (*a == 'a')
@@ -402,32 +407,92 @@ cdinfo_tmpl_to_url(char *tmpl, char *url, int trkpos)
 				MEM_FREE(q);
 				break;
 
+			case 'R':
+			case 'r':
+				/* Translate track artist into a
+				 * keyword string in CGI form
+				 */
+				if (trkpos >= 0 &&
+				    cdinfo_db.track[trkpos].artist != NULL) {
+					q = cdinfo_txtreduce(
+						cdinfo_db.track[trkpos].artist,
+						(bool_t) (*a == 'r')
+					);
+					if (q == NULL) {
+						CDINFO_FATAL(
+							app_data.str_nomemory
+						);
+						return;
+					}
+					strcpy(r, q);
+					r += strlen(q);
+					MEM_FREE(q);
+					break;
+				}
+
+				if (cdinfo_db.disc.artist == NULL)
+					break;
+
+				/* Can't do track, Use disc artist instead */
+				q = cdinfo_txtreduce(cdinfo_db.disc.artist,
+						      (bool_t) (*a == 'r'));
+				if (q == NULL) {
+					CDINFO_FATAL(app_data.str_nomemory);
+					return;
+				}
+
+				(void) strcpy(r, q);
+				r += strlen(q);
+				MEM_FREE(q);
+				break;
+
 			case 'T':
 			case 't':
 				/* Translate track title into a
 				 * keyword string in CGI form
 				 */
-				if (trkpos >= 0) {
+				if (trkpos >= 0 &&
+				    cdinfo_db.track[trkpos].title != NULL) {
 					q = cdinfo_txtreduce(
 						cdinfo_db.track[trkpos].title,
 						(bool_t) (*a == 't')
 					);
 					if (q == NULL) {
-					    CDINFO_FATAL(app_data.str_nomemory);
-					    return;
+						CDINFO_FATAL(
+							app_data.str_nomemory
+						);
+						return;
 					}
 					strcpy(r, q);
 					r += strlen(q);
 					MEM_FREE(q);
 					break;
 				}
-				/*FALLTHROUGH*/
+
+				if (cdinfo_db.disc.title == NULL)
+					break;
+
+				/* Can't do track, Use disc title instead */
+				q = cdinfo_txtreduce(cdinfo_db.disc.title,
+						      (bool_t) (*a == 't'));
+				if (q == NULL) {
+					CDINFO_FATAL(app_data.str_nomemory);
+					return;
+				}
+
+				(void) strcpy(r, q);
+				r += strlen(q);
+				MEM_FREE(q);
+				break;
 
 			case 'D':
 			case 'd':
 				/* Translate disc title into a
 				 * keyword string in CGI form
 				 */
+				if (cdinfo_db.disc.title == NULL)
+					break;
+
 				q = cdinfo_txtreduce(cdinfo_db.disc.title,
 						      (bool_t) (*a == 'd'));
 				if (q == NULL) {
@@ -445,6 +510,10 @@ cdinfo_tmpl_to_url(char *tmpl, char *url, int trkpos)
 				/* Translate artist and disc title into a
 				 * keyword string in CGI form
 				 */
+				if (cdinfo_db.disc.artist == NULL &&
+				    cdinfo_db.disc.title == NULL)
+					break;
+
 				(void) sprintf(dtitle, "%.127s%s%.127s",
 					(cdinfo_db.disc.artist == NULL) ?
 						"" : cdinfo_db.disc.artist,
@@ -453,6 +522,7 @@ cdinfo_tmpl_to_url(char *tmpl, char *url, int trkpos)
 						" / " : "",
 					(cdinfo_db.disc.title == NULL) ?
 						"" : cdinfo_db.disc.title);
+
 				q = cdinfo_txtreduce(
 					dtitle,
 					(bool_t) (*a == 'b')
@@ -467,6 +537,14 @@ cdinfo_tmpl_to_url(char *tmpl, char *url, int trkpos)
 				MEM_FREE(q);
 				break;
 
+			case '#':
+				if (trkpos >= 0) {
+					(void) sprintf(r, "%02d",
+						    s->trkinfo[trkpos].trkno);
+					r += 2;
+				}
+				break;
+
 			case '%':
 				*r++ = '%';
 				break;
@@ -477,6 +555,7 @@ cdinfo_tmpl_to_url(char *tmpl, char *url, int trkpos)
 				break;
 			}
 			break;
+
 		default:
 			*r++ = *a;
 			break;
@@ -517,19 +596,27 @@ cdinfo_url_len(char *tmpl, url_attrib_t *up, int *trkpos)
 
 	if (*trkpos < 0 || cdinfo_db.track[*trkpos].title == NULL) {
 		*trkpos = -1;
-		n += (up->tcnt * dtitle_len);
+		n += ((up->rcnt * dtitle_len) + (up->tcnt * dtitle_len));
+	}
+	else {
+		n += (up->tcnt * strlen(cdinfo_db.track[*trkpos].title));
+
+		if (cdinfo_db.track[*trkpos].artist != NULL)
+		    n += (up->rcnt * strlen(cdinfo_db.track[*trkpos].artist));
+		else
+		    n += (up->rcnt * artist_len);
 	}
-	else
-		n += strlen(cdinfo_db.track[*trkpos].title);
 
 	n += (up->xcnt * strlen(cdinfo_clinfo->prog));
 	n += (up->vcnt * (strlen(VERSION_MAJ) + strlen(VERSION_MIN) + 1));
 	n += (up->ncnt * STR_BUF_SZ);
 	n += (up->hcnt * MAXHOSTNAMELEN);
 	n += (up->lcnt * strlen(app_data.libdir));
-	if (cdinfo_db.disc.genre != NULL)
+	n += (up->pcnt * 2);
+	if (cdinfo_db.disc.genre != NULL) {
 		n += (up->ccnt *
 		      strlen(cdinfo_genre_path(cdinfo_db.disc.genre)));
+	}
 	n += (up->icnt * 8);
 	n++;
 
@@ -640,7 +727,7 @@ cdinfo_submit(curstat_t *s)
 		return (retcode);
 
 	/* Open CDDB connection */
-	if ((cp = cdinfo_opencddb(s, &retcode)) == NULL) {
+	if ((cp = cdinfo_opencddb(s, FALSE, &retcode)) == NULL) {
 		/* CDDB service failure */
 		CH_RET(retcode);
 	}
@@ -687,7 +774,7 @@ cdinfo_submit_url(curstat_t *s, cdinfo_url_t *up)
 		return (retcode);
 
 	/* Open CDDB connection */
-	if ((cp = cdinfo_opencddb(s, &retcode)) == NULL) {
+	if ((cp = cdinfo_opencddb(s, FALSE, &retcode)) == NULL) {
 		/* CDDB service failure */
 		CH_RET(retcode);
 	}
@@ -729,7 +816,7 @@ cdinfo_flush(curstat_t *s)
 		return (retcode);
 
 	/* Open CDDB connection */
-	if ((cp = cdinfo_opencddb(s, &retcode)) == NULL) {
+	if ((cp = cdinfo_opencddb(s, FALSE, &retcode)) == NULL) {
 		/* CDDB service failure */
 		CH_RET(retcode);
 	}
@@ -771,7 +858,7 @@ cdinfo_offline(curstat_t *s)
 		return (retcode);
 
 	/* Open CDDB connection */
-	if ((cp = cdinfo_opencddb(s, &retcode)) == NULL) {
+	if ((cp = cdinfo_opencddb(s, FALSE, &retcode)) == NULL) {
 		/* CDDB service failure */
 		CH_RET(retcode);
 	}
@@ -827,13 +914,17 @@ cdinfo_load(curstat_t *s)
 		DBGPRN(DBG_CDI)(errfp, "Initializing CDDB service...\n");
 
 		/* Open CDDB connection */
-		if ((cp = cdinfo_opencddb(s, &retcode)) != NULL) {
+		if ((cp = cdinfo_opencddb(s, TRUE, &retcode)) != NULL) {
 			/* Check user registration, set up region, role
 			 * and genre lists
 			 */
 			(void) cdinfo_initcddb(cp, &retcode);
 			(void) cdinfo_closecddb(cp);
 		}
+		else if (retcode == AUTH_ERR) {
+			/* Special case handling for proxy auth error */
+			return CDINFO_SET_CODE(retcode, 0);
+		}
 	}
 
 	for (pp = cdinfo_db.pathlist; pp != NULL; pp = pp->next) {
@@ -846,8 +937,15 @@ cdinfo_load(curstat_t *s)
 			DBGPRN(DBG_CDI)(errfp, "Trying CDDB service...\n");
 
 			/* Open CDDB connection */
-			if ((cp = cdinfo_opencddb(s, &retcode)) == NULL) {
+			if ((cp = cdinfo_opencddb(s, TRUE, &retcode)) == NULL)
+			{
 				/* CDDB service failure */
+				if (retcode == AUTH_ERR) {
+					/* Special case handling for
+					 * proxy auth error
+					 */
+					return CDINFO_SET_CODE(retcode, 0);
+				}
 				break;
 			}
 
@@ -1135,6 +1233,8 @@ cdinfo_load(curstat_t *s)
 			return CDINFO_SET_CODE(KILLED_ERR, WTERMSIG(stat_val));
 		else
 			return 0;
+
+		/*NOTREACHED*/
 	}
 
 	if (cdinfo_cddb_iscfg() &&
@@ -1144,13 +1244,17 @@ cdinfo_load(curstat_t *s)
 		DBGPRN(DBG_CDI)(errfp, "Initializing CDDB service...\n");
 
 		/* Open CDDB connection */
-		if ((cp = cdinfo_opencddb(s, &retcode)) != NULL) {
+		if ((cp = cdinfo_opencddb(s, TRUE, &retcode)) != NULL) {
 			/* Check user registration, set up region, role
 			 * and genre lists
 			 */
 			(void) cdinfo_initcddb(cp, &retcode);
 			(void) cdinfo_closecddb(cp);
 		}
+		else if (retcode == AUTH_ERR) {
+			/* Special case handling for proxy auth error */
+			CH_RET(retcode);
+		}
 	}
 
 	done = FALSE;
@@ -1164,8 +1268,15 @@ cdinfo_load(curstat_t *s)
 			DBGPRN(DBG_CDI)(errfp, "Trying CDDB service...\n");
 
 			/* Open CDDB connection */
-			if ((cp = cdinfo_opencddb(s, &retcode)) == NULL) {
-				/* Failure */
+			if ((cp = cdinfo_opencddb(s, TRUE, &retcode)) == NULL)
+			{
+				/* CDDB service Failure */
+				if (retcode == AUTH_ERR) {
+					/* Special case handling for
+					 * proxy auth error
+					 */
+					CH_RET(retcode);
+				}
 				break;
 			}
 
@@ -1843,7 +1954,7 @@ cdinfo_reguser(curstat_t *s)
 	}
 
 	/* Open CDDB connection */
-	if ((cp = cdinfo_opencddb(s, &retcode)) == NULL)
+	if ((cp = cdinfo_opencddb(s, FALSE, &retcode)) == NULL)
 		CH_RET(retcode);
 
 	/* Register user with CDDB */
@@ -1885,7 +1996,7 @@ cdinfo_getpasshint(curstat_t *s)
 		return (retcode);
 
 	/* Open CDDB connection */
-	if ((cp = cdinfo_opencddb(s, &retcode)) == NULL)
+	if ((cp = cdinfo_opencddb(s, FALSE, &retcode)) == NULL)
 		CH_RET(retcode);
 
 	/* Ask CDDB to send password hint */
@@ -1924,7 +2035,7 @@ cdinfo_go_musicbrowser(curstat_t *s)
 		return (retcode);
 
 	/* Open CDDB connection */
-	if ((cp = cdinfo_opencddb(s, &retcode)) == NULL) {
+	if ((cp = cdinfo_opencddb(s, FALSE, &retcode)) == NULL) {
 		/* Failure */
 		CH_RET(retcode);
 	}
@@ -2006,7 +2117,7 @@ cdinfo_go_cddburl(curstat_t *s, int type, int idx)
 		return (retcode);
 
 	/* Open CDDB connection */
-	if ((cp = cdinfo_opencddb(s, &retcode)) == NULL) {
+	if ((cp = cdinfo_opencddb(s, FALSE, &retcode)) == NULL) {
 		/* Failure */
 		CH_RET(retcode);
 	}
@@ -2075,7 +2186,7 @@ cdinfo_gen_discog(curstat_t *s)
 		CH_RET(ENOMEM);
 	}
 	/* Make the URL from template */
-	cdinfo_tmpl_to_url(cdinfo_discog->arg, url, i);
+	cdinfo_tmpl_to_url(s, cdinfo_discog->arg, url, i);
 
 	if (util_urlchk(url, &path, &n) & IS_REMOTE_URL) {
 		/* Error: local discography cannot be remote */
@@ -2599,13 +2710,7 @@ cdinfo_genre_path(char *id)
 			return ("");
 		}
 
-		(void) strcpy(buf, cp);
-#ifdef __VMS
-		(void) strcat(buf, ".");
-#else
-		(void) strcat(buf, "/");
-#endif
-		(void) strcat(buf, cp2);
+		(void) sprintf(buf, "%s%c%s", cp, DIR_SEP, cp2);
 		MEM_FREE(cp);
 		MEM_FREE(cp2);
 
