@@ -6,7 +6,7 @@
  *	libdi - CD Audio Player Device Interface Library
  *
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,7 @@
 #define __APPENV_H__
 
 #ifndef LINT
-static char *_appenv_h_ident_ = "@(#)appenv.h	7.45 01/07/26";
+static char *_appenv_h_ident_ = "@(#)appenv.h	7.74 02/04/07";
 #endif
 
 
@@ -104,6 +104,12 @@ static char *_appenv_h_ident_ = "@(#)appenv.h	7.45 01/07/26";
 #define READDIR		readdir
 #define CLOSEDIR	closedir
 
+#ifdef NO_SETSID
+#define SETSID		setpgrp
+#else
+#define SETSID		setsid
+#endif
+
 #else
 /* OpenVMS */
 
@@ -404,17 +410,36 @@ typedef struct url_attrib {
 	int		icnt;			/* Count of %I */
 	int		acnt;			/* Count of %A and %a */
 	int		dcnt;			/* Count of %D and %d */
+	int		rcnt;			/* Count of %R and %r */
 	int		tcnt;			/* Count of %T and %t */
+	int		pcnt;			/* Count of %# */
 } url_attrib_t;
 
 
+/*
+ * Defines for channel routing modes
+ */
+#define CHROUTE_NORMAL		0		/* Normal stereo */
+#define CHROUTE_REVERSE		1		/* Reverse stereo */
+#define CHROUTE_L_MONO		2		/* Left channel mono */
+#define CHROUTE_R_MONO		3		/* Right channel mono */
+#define CHROUTE_MONO		4		/* Left+Right channel mono */
+
+
+/*
+ * Defines for volume control taper
+ */
+#define VOLTAPER_LINEAR		0		/* Linear taper */
+#define VOLTAPER_SQR		1		/* Square taper */
+#define VOLTAPER_INVSQR		2		/* Inverse square */
+
+
 /*
  * Defines for the type field in trkinfo_t
  */
 #define TYP_AUDIO		1		/* Audio track */
 #define TYP_DATA		2		/* Data track */
 
-
 /*
  * Defines for the mode field in curstat_t
  */
@@ -425,7 +450,6 @@ typedef struct url_attrib {
 #define MOD_SAMPLE		4		/* Sample mode */
 #define MOD_BUSY		5		/* Drive is busy */
 
-
 /*
  * Defines for the segplay field in curstat_t
  */
@@ -448,10 +472,10 @@ typedef struct url_attrib {
  */
 #define TIMEDPY_MAX_MODES	6		/* Max number of modes */
 #define T_ELAPSED_TRACK		0		/* Per-track elapsed time */
-#define T_ELAPSED_SEG		1		/* Per-segment elapsed time */
+#define T_ELAPSED_SEG		1		/* Per-seg elapsed time */
 #define T_ELAPSED_DISC		2		/* Whole-disc elapsed time */
 #define T_REMAIN_TRACK		3		/* Per-track remaining time */
-#define T_REMAIN_SEG		4		/* Per-segment remaining time */
+#define T_REMAIN_SEG		4		/* Per-seg remaining time */
 #define T_REMAIN_DISC		5		/* Whole-disc remaining time */
 
 /*
@@ -462,6 +486,56 @@ typedef struct url_attrib {
 #define QMODE_MATCH		2		/* CD info match found */
 #define QMODE_ERR		3		/* CD info error */
 
+/*
+ * Defines for the status field in cdstat_t
+ */
+#define CDSTAT_PLAYING		0x11		/* Audio play in progress */
+#define CDSTAT_PAUSED		0x12		/* Audio play paused */
+#define CDSTAT_COMPLETED	0x13		/* Audio play completed */
+#define CDSTAT_FAILED		0x14		/* Audio play error */
+#define CDSTAT_NOSTATUS		0x15		/* No audio status */
+
+/*
+ * Defines for the play_mode field in appdata_t
+ * More than one CDDA mode can be enabled at a time.
+ */
+#define PLAYMODE_STD		0x00		/* Standard playback mode */
+#define PLAYMODE_CDDA		0x01		/* CDDA playback mode */
+#define PLAYMODE_FILE		0x02		/* CDDA save-to-file mode */
+#define PLAYMODE_PIPE		0x04		/* CDDA pipe-to-program mode */
+
+#define PLAYMODE_IS_STD(x)	((x) == 0)
+#define PLAYMODE_IS_CDDA(x)	((x) != 0)
+
+/*
+ * Defines for the filefmt field in appdata_t
+ */
+#define FILEFMT_RAW		0		/* RAW (headerless) format */
+#define FILEFMT_AU		1		/* AU format */
+#define FILEFMT_WAV		2		/* WAV format */
+#define FILEFMT_AIFF		3		/* AIFF format */
+#define FILEFMT_AIFC		4		/* AIFF-C format */
+
+
+/*
+ * CD position MSF structure
+ */
+typedef struct msf {
+	byte_t		res;		/* reserved */
+	byte_t		min;		/* minutes */
+	byte_t		sec;		/* seconds */
+	byte_t		frame;		/* frame */
+} msf_t;
+
+
+/*
+ * Combined MSF and logical address union
+ */
+typedef union lmsf {
+	msf_t		msf;		/* MSF address */
+	word32_t	logical;	/* logical address */
+} lmsf_t;
+
 
 /*
  * CD per-track information
@@ -473,10 +547,14 @@ typedef struct {
 	byte_t		sec;			/* Absolute offset seconds */
 	byte_t		frame;			/* Absolute offset frame */
 	byte_t		type;			/* track type */
+	sword32_t	playorder;		/* Prog/Shuf sequence */
+	char		*outfile;		/* Cooked audio file paths */
 } trkinfo_t;
 
 
-/* CD position information */
+/*
+ * CD position information
+ */
 typedef struct {
 	word32_t	addr;
 	byte_t		min;
@@ -486,6 +564,21 @@ typedef struct {
 } cdpos_t;
 
 
+/* CDDA status structure */
+typedef struct {
+	byte_t		status;			/* Play status */
+	byte_t		track;			/* Track number */
+	byte_t		index;			/* Index number */
+	byte_t		rsvd;
+	cdpos_t		abs_addr;		/* Absolute address */
+	cdpos_t		rel_addr;		/* Track-relative address */
+	byte_t		level;			/* Current volume level */
+	byte_t		level_left;		/* Current left volume % */
+	byte_t		level_right;		/* Current right volume % */
+	byte_t		rsvd2;
+} cdstat_t;
+
+
 /*
  * Structure containing current status information
  */
@@ -521,7 +614,6 @@ typedef struct {
 	word32_t	rptcnt;			/* Repeat iteration count */
 
 	trkinfo_t	trkinfo[MAXTRACK];	/* Per-track information */
-	sword32_t	playorder[MAXTRACK];	/* Prog/Shuf sequence */
 
 	bool_t		devlocked;		/* Device locked */
 	bool_t		repeat;			/* Repeat mode */
@@ -530,12 +622,16 @@ typedef struct {
 	bool_t		onetrk_prog;		/* Trk list 1-track program */
 	bool_t		caddy_lock;		/* Caddy lock */
 	bool_t		chgrscan;		/* Changer scan in process */
+	bool_t		rsvd0;			/* reserved */
 	byte_t		qmode;			/* CD info query mode */
 	byte_t		prog_tot;		/* Prog/Shuf total tracks */
 	byte_t		prog_cnt;		/* Prog/Shuf track counter */
 	byte_t		level;			/* Current volume level */
 	byte_t		level_left;		/* Left channel vol percent */
 	byte_t		level_right;		/* Right channel vol percent */
+	byte_t		rsvd1[2];		/* reserved */
+	char		*outf_tmpl;		/* Audio file path template */
+	char		*pipeprog;		/* Pgm to pipe audio data to */
 	char		vendor[9];		/* CD-ROM drive vendor */
 	char		prod[17];		/* CD-ROM drive model */
 	char		revnum[5];		/* CD-ROM firmware revision */
@@ -615,10 +711,6 @@ installation instructions."
 #define STR_SAVERR_CLOSE	"File not saved:\nCannot save file."
 #define STR_SAVERR_WRITE	"File save error!"
 #define STR_SAVERR_KILLED	"File not saved:\nChild killed. (signal %d)"
-#define STR_LNKERR_FORK		"File not linked:\nCannot fork. (errno %d)"
-#define STR_LNKERR_SUID		"File not linked:\nCannot setuid to %d."
-#define STR_LNKERR_LINK		"File not linked:\nLink failed."
-#define STR_LNKERR_KILLED	"File not linked:\nChild killed. (signal %d)"
 #define STR_CHGSUBMIT		\
 "%s\n%s\n\n\
 The on-screen CD database information has changed.\n\
@@ -729,6 +821,29 @@ and end point track and frame numbers."
 Check the start and end point track and frame\n\
 numbers."
 #define STR_DISCARDCHG		"Do you want to discard your changes?"
+#define STR_NOAUDIOPATH		"No output audio file name specified."
+#define STR_AUDIOPATHEXISTS	"Cannot write audio file: file exists."
+#define STR_PLAYBACKMODE	"Playback mode"
+#define STR_AUTOFUNCS		"Automated functions"
+#define STR_CDCHANGER		"CD changer"
+#define STR_CHROUTE		"Channel routing"
+#define STR_VOLBAL		"Volume / Balance"
+#define STR_CDDAINIT_FAIL	\
+"Cannot initialize CDDA.  Possible causes are:\n\n\
+- An error condition as described above, if displayed.\n\
+- The cddaMethod, cddaReadMethod or cddaWriteMethod\n\
+  parameters may be misconfigured.\n\
+- There is no CDDA support for your CD drive or\n\
+  OS platform in this version.\n\n\
+See your xmcd documentation for information."
+#define STR_FILENAMEREQ		"You must select or enter a file name."
+#define STR_NOTREGFILE		\
+"The file name you selected or entered\n\
+is not a regular file."
+#define STR_NOPROG		"CDDA pipe to program: No program specified."
+#define STR_OVERWRITE		\
+"The output audio file exists.\n\
+Do you want to overwrite it?"
 
 
 /*
@@ -750,7 +865,7 @@ typedef struct {
 	bool_t		main_showfocus;		/* Highlight kbd focus? */
 	bool_t		instcmap;		/* Install colormap? */
 	bool_t		remotemode;		/* Remote ctrl mode */
-	bool_t		rsvd;			/* Reserved */
+	bool_t		rsvd;			/* reserved */
 	char		*remotehost;		/* Remote ctrl client host */
 
 	/*
@@ -804,6 +919,11 @@ typedef struct {
 	int		chg_method;		/* Medium change method */
 	int		base_scsivol;		/* SCSI volume value base */
 	int		min_playblks;		/* Minimum play blocks */
+	int		cdda_method;		/* CDDA method */
+	int		cdda_rdmethod;		/* CDDA read method */
+	int		cdda_wrmethod;		/* CDDA write method */
+	int		cdda_scsireadcmd;	/* CDDA SCSI vendor cmd set */
+	int		cdda_scsidensity;	/* CDDA SCSI modesel density */
 	bool_t		scsiverck;		/* SCSI version check */
 	bool_t		play10_supp;		/* Play Audio (10) supported */
 	bool_t		play12_supp;		/* Play Audio (12) supported */
@@ -812,6 +932,7 @@ typedef struct {
 	bool_t		load_supp;		/* Motorized load supported */
 	bool_t		eject_supp;		/* Motorized eject supported */
 	bool_t		msen_dbd;		/* Set DBD bit for msense */
+	bool_t		msen_10;		/* Use 10-byte mode sen/sel */
 	bool_t		mselvol_supp;		/* Audio vol chg supported */
 	bool_t		balance_supp;		/* Indep vol chg supported */
 	bool_t		chroute_supp;		/* Channel routing support */
@@ -823,11 +944,15 @@ typedef struct {
 	bool_t		play_notur;		/* No Tst U Rdy when playing */
 	bool_t		toc_lba;		/* Rd TOC in LBA mode */
 	bool_t		subq_lba;		/* Rd Subchan in LBA mode */
-	bool_t		rsvd2;			/* Reserved */
+	bool_t		cdda_bigendian;		/* CDDA is in big endian */
+	bool_t		cdda_modesel;		/* Do mode select for CDDA */
+	bool_t		rsvd0[2];		/* reserved */
+
 	int		drv_blksz;		/* Drive native block size */
 	int		spinup_interval;	/* spin up delay (sec) */
 
 	/* User-modifiable */
+	int		play_mode;		/* Playback mode */
 	int		vol_taper;		/* Volume control taper */
 	int		startup_vol;		/* Startup volume preset */
 	int		ch_route;		/* Channel routing */
@@ -836,6 +961,9 @@ typedef struct {
 	int		skip_spdup;		/* FF/REW speedup count */
 	int		skip_vol;		/* FF/REW percent volume */
 	int		skip_minvol;		/* FF/REW minimum volume */
+	int		cdda_readchkblks;	/* CDDA read chunk */
+	int		cdda_filefmt;		/* Output file format */
+	int		rsvd1;			/* reserved */
 	bool_t		load_spindown;		/* Spin down disc on CD load */
 	bool_t		load_play;		/* Auto play on CD load */
 	bool_t		done_eject;		/* Auto eject on done */
@@ -849,7 +977,9 @@ typedef struct {
 	bool_t		shuffle_mode;		/* Shuffle enable on startup */
 	bool_t		multi_play;		/* Multi-CD playback */
 	bool_t		reverse;		/* Multi-CD reverse playback */
-	bool_t		rsvd3[3];		/* Reserved */
+	bool_t		cdda_jitter_corr;	/* Do CDDA jitter correction */
+	bool_t		cdda_trkfile;		/* One output file per track */
+	bool_t		rsvd2;			/* reserved */
 
 	/*
 	 * Various application message strings
@@ -911,10 +1041,6 @@ typedef struct {
 	char		*str_saverr_close;	/* File save err: close */
 	char		*str_saverr_write;	/* File save err: write */
 	char		*str_saverr_killed;	/* File save err: child kill */
-	char		*str_lnkerr_fork;	/* File link err: fork */
-	char		*str_lnkerr_suid;	/* File link err: setuid */
-	char		*str_lnkerr_link;	/* File link err: link */
-	char		*str_lnkerr_killed;	/* File link err: child kill */
 	char		*str_chgsubmit;		/* Submit change dialog msg */
 	char		*str_devlist_undef;	/* deviceList no defined */
 	char		*str_devlist_count;	/* deviceList count wrong */
@@ -966,6 +1092,18 @@ typedef struct {
 	char		*str_incseginfo;	/* Incomplete segment info */
 	char		*str_invseginfo;	/* Invalid segment info */
 	char		*str_discardchg;	/* Discard change? */
+	char		*str_noaudiopath;	/* Audio file path missing */
+	char		*str_audiopathexists;	/* Audio file exists */
+	char		*str_playbackmode;	/* Playback mode */
+	char		*str_autofuncs;		/* Automated functions */
+	char		*str_cdchanger;		/* CD changer */
+	char		*str_chroute;		/* Channel routing */
+	char		*str_volbal;		/* Volume / Balance */
+	char		*str_cddainit_fail;	/* CDDA init failure */
+	char		*str_filenamereq;	/* File name required */
+	char		*str_notregfile;	/* Not a regular file */
+	char		*str_noprog;		/* No CDDA program specified */
+	char		*str_overwrite;		/* Overwrite file? */
 
 	/*
 	 * Short-cut key translations
