@@ -6,7 +6,7 @@
  *   libdi - CD Audio Player Device Interface Library
  *
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,7 @@
 #define __UTIL_H__
 
 #ifndef LINT
-static char *_util_h_ident_ = "@(#)util.h	6.34 01/04/10";
+static char *_util_h_ident_ = "@(#)util.h	6.38 02/05/04";
 #endif
 
 
@@ -37,10 +37,12 @@ static char *_util_h_ident_ = "@(#)util.h	6.34 01/04/10";
 #define DIR_BEG		'['		/* Directory start */
 #define DIR_SEP		'.'		/* Directory separator */
 #define DIR_END		']'		/* Directory end */
+#define CUR_DIR		"[]"		/* Current directory */
 #else
 #define DIR_BEG		'/'		/* Directory start */
 #define DIR_SEP		'/'		/* Directory separator */
 #define DIR_END		'/'		/* Directory end */
+#define CUR_DIR		"."		/* Current directory */
 #endif
 
 /* Utility macros */
@@ -99,6 +101,10 @@ extern void		util_blktomsf(word32_t, byte_t *, byte_t *, byte_t *,
 				      word32_t);
 extern void		util_msftoblk(byte_t, byte_t, byte_t, word32_t *,
 				      word32_t);
+extern int		util_taper_vol(int);
+extern int		util_untaper_vol(int);
+extern int		util_scale_vol(int);
+extern int		util_unscale_vol(int);
 extern void		util_delayms(unsigned long);
 extern char		*util_strstr(char *s1, char *s2);
 extern int		util_strcasecmp(char *, char *);
@@ -107,6 +113,9 @@ extern char		*util_text_reduce(char *);
 extern char		*util_cgi_xlate(char *);
 extern int		util_urlchk(char *, char **, int *);
 extern void		util_html_fputs(char *, FILE *, bool_t, char *, int);
+extern void		*util_open_lconv(char *, char *);
+extern void		util_close_lconv(void *);
+extern bool_t		util_do_lconv(void *, char *, char **);
 extern word16_t		util_bswap16(word16_t);
 extern word32_t		util_bswap24(word32_t);
 extern word32_t		util_bswap32(word32_t);
