@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# @(#)install.sh	7.57 01/06/24
+# @(#)install.sh	7.64 02/01/14
 #
 # Script to install the software binary and support files on
 # the target system.
@@ -12,7 +12,6 @@
 #	The following environment variables can be used to override the
 #	default answers:
 #	BATCH_BINDIR		Binary executable installation directory
-#	BATCH_LIBDIR		X11 library directory
 #	BATCH_XMCDLIB		Xmcd support files top level directory
 #	BATCH_DISCOGDIR		Local discographies top level directory
 #	BATCH_MANDIR		Manual page top level directory
@@ -21,7 +20,7 @@
 #    xmcd  - Motif(tm) CD Audio Player
 #    cda   - Command-line CD Audio Player
 #
-#    Copyright (C) 1993-2001  Ti Kan
+#    Copyright (C) 1993-2002  Ti Kan
 #    E-mail: xmcd@amb.org
 #
 #    This program is free software; you can redistribute it and/or modify
@@ -43,7 +42,7 @@ OPATH="$PATH"
 PATH=/bin:/usr/bin:/sbin:/usr/sbin:/etc:/usr/local/bin
 export PATH
 
-XMCD_VER=3.0
+XMCD_VER=3.1
 XMCD_URL=http://www.amb.org/xmcd/
 DIRPERM=755
 SCRPERM=755
@@ -466,7 +465,7 @@ fix_discog()
 	    fi
 	done | \
 	sed -e "s/Generated by xmcd 2\..*$/Generated by xmcd $XMCD_VER/" \
-	    -e 's/Copyright .* Ti Kan/Copyright (C) 1993-2001  Ti Kan/' \
+	    -e 's/Copyright .* Ti Kan/Copyright (C) 1993-2002  Ti Kan/' \
 	    -e 's/Browse .* Xmcd web site/Xmcd official web site/' \
 	    -e 's/Browse .* CDDB web site/CDDB - The #1 music info source/' \
 	    -e 's/Browse music reviews/Yahoo! music reviews/' \
@@ -795,17 +794,27 @@ else
 	do
 		if get_str "\n  Enter X binary directory\n  [${BINDIR}]:"
 		then
-			if echo "$ANS" | grep "^/" >/dev/null 2>&1
+			UDIR="$ANS"
+			if echo "$UDIR" | grep "^/" >/dev/null 2>&1
 			then
-				if [ -d "$ANS" ]
+			    if [ -d "$UDIR" ]
+			    then
+				BINDIR="$UDIR"
+				break
+			    else
+				YNDEF=y
+				if get_yn \
+				"  Directory $UDIR does not exist.  Create it"
 				then
-					BINDIR=$ANS
-					break
+				    BINDIR="$UDIR"
+				    break
 				else
-					$ECHO "  Error: $ANS does not exist."
+				    $ECHO \
+				    "  Error: Cannot install in ${UDIR}."
 				fi
+			    fi
 			else
-				$ECHO "  Error: You must use an absolute path."
+			    $ECHO "  Error: You must use an absolute path."
 			fi
 		else
 			break
@@ -846,39 +855,6 @@ else
 	LIBDIR=`echo $LIBDIR | sed 's/\/\//\//g'`
 fi
 
-$ECHO "\n\nThe X library directory is where the X window system"
-$ECHO "configuration files are located."
-
-if [ -n "$BATCH" ]
-then
-	if [ -n "$BATCH_LIBDIR" ]
-	then
-		LIBDIR=$BATCH_LIBDIR
-	fi
-	$ECHO "\nUsing $LIBDIR"
-else
-	while :
-	do
-		if get_str "\n  Enter X library directory\n  [${LIBDIR}]:"
-		then
-			if echo "$ANS" | grep "^/" >/dev/null 2>&1
-			then
-				if [ -d "$ANS" ]
-				then
-					LIBDIR=$ANS
-					break
-				else
-					$ECHO "  Error: $ANS does not exist."
-				fi
-			else
-				$ECHO "  Error: You must use an absolute path."
-			fi
-		else
-			break
-		fi
-	done
-fi
-
 
 # Determine xmcd libdir
 
@@ -904,7 +880,7 @@ else
 			then
 			    if [ -d "$UDIR" ]
 			    then
-				XMCDLIB=$UDIR
+				XMCDLIB="$UDIR"
 				break
 			    else
 				if get_yn \
@@ -918,7 +894,7 @@ else
 				fi
 			    fi
 			else
-				$ECHO "  Error: You must use an absolute path."
+			    $ECHO "  Error: You must use an absolute path."
 			fi
 		else
 			break
@@ -1118,6 +1094,10 @@ ARCHLIB="${XMCDLIB}/lib-${OS_SYS_T}-${OS_MACH_T}"
 # Make all necessary directories
 $ECHO "\n\nMaking directories..."
 
+if [ ! -d "$BINDIR" ]
+then
+	make_dir $BINDIR $DIRPERM $OWNER $GROUP
+fi
 make_dir $XMCDLIB $DIRPERM $OWNER $GROUP
 make_dir $XMCDLIB/app-defaults $DIRPERM $OWNER $GROUP
 make_dir $XMCDLIB/config $DIRPERM $OWNER $GROUP
@@ -1160,7 +1140,6 @@ fi
 
 SHELL_S=`echo $SHELL | sed 's/\//\\\\\//g'`
 BINDIR_S=`echo $BINDIR | sed 's/\//\\\\\//g'`
-LIBDIR_S=`echo $LIBDIR | sed 's/\//\\\\\//g'`
 XMCDLIB_S=`echo $XMCDLIB | sed 's/\//\\\\\//g'`
 DISCOGDIR_S=`echo $DISCOGDIR | sed 's/\//\\\\\//g'`
 XMCDURL_S=`echo $XMCD_URL | sed 's/\//\\\\\//g'`
@@ -1257,7 +1236,6 @@ done
 # Configuration script
 sed -e "s/^#!\/bin\/sh.*/#!$SHELL_S/" \
     -e "s/^BINDIR=.*/BINDIR=$BINDIR_S/" \
-    -e "s/^LIBDIR=.*/LIBDIR=$LIBDIR_S/" \
     -e "s/^XMCDLIB=.*/XMCDLIB=$XMCDLIB_S/" \
     -e "s/^DISCOGDIR=.*/DISCOGDIR=$DISCOGDIR_S/" \
     -e "s/^XMCD_URL=.*/XMCD_URL=$XMCDURL_S/" \
@@ -1289,7 +1267,6 @@ done
 
 sed -e "s/^#!\/bin\/sh.*/#!$SHELL_S/" \
     -e "s/^BINDIR=.*/BINDIR=$BINDIR_S/" \
-    -e "s/^LIBDIR=.*/LIBDIR=$LIBDIR_S/" \
     -e "s/^XMCDLIB=.*/XMCDLIB=$XMCDLIB_S/" \
     -e "s/^DISCOGDIR=.*/DISCOGDIR=$DISCOGDIR_S/" \
     -e "s/^XMCD_URL=.*/XMCD_URL=$XMCDURL_S/" \
@@ -1307,7 +1284,6 @@ inst_file misc_d/xmcdlogo.gif $DISCOGDIR/xmcdlogo.gif $FILEPERM $OWNER $GROUP
 rm -f $DISCOGDIR/discog.html
 sed -e "s/\$SHELL/$SHELL_S/g" \
     -e "s/\$BINDIR/$BINDIR_S/g" \
-    -e "s/\$LIBDIR/$LIBDIR_S/g" \
     -e "s/\$XMCDLIB/$XMCDLIB_S/g" \
     -e "s/file:\/\/localhost\/\$DISCOGDIR/file:\/\/localhost$DISCOGDIR_S/g" \
     -e "s/\$DISCOGDIR/$DISCOGDIR_S/g" \
@@ -1544,7 +1520,7 @@ then
 		newgenre=Unclassifiable/General_Unclassifiable
 		;;
 	    newage)
-		newgenre=Newage/General_Newage
+		newgenre=New_Age/General_New_Age
 		;;
 	    reggae)
 		newgenre=World/Reggae
