@@ -1,7 +1,7 @@
 /*
  *   libdi - CD Audio Player Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -24,7 +24,7 @@
 #if defined(DI_AIXIOC) && !defined(DEMO_ONLY)
 
 #ifndef LINT
-static char *_aixioc_h_ident_ = "@(#)aixioc.h	6.12 01/04/17";
+static char *_aixioc_h_ident_ = "@(#)aixioc.h	6.14 02/03/31";
 #endif
 
 #include <sys/devinfo.h>
@@ -42,6 +42,7 @@ typedef struct {
  * Public functions
  */
 extern void	aixioc_init(curstat_t *, di_tbl_t *);
+extern bool_t	aixioc_playmode(curstat_t *);
 extern bool_t	aixioc_check_disc(curstat_t *);
 extern void	aixioc_status_upd(curstat_t *);
 extern void	aixioc_lock(curstat_t *, bool_t);
@@ -64,6 +65,8 @@ extern void	aixioc_warp(curstat_t *);
 extern void	aixioc_route(curstat_t *);
 extern void	aixioc_mute_on(curstat_t *);
 extern void	aixioc_mute_off(curstat_t *);
+extern void	aixioc_cddajitter(curstat_t *);
+extern void	aixioc_debug(void);
 extern void	aixioc_start(curstat_t *);
 extern void	aixioc_icon(curstat_t *, bool_t);
 extern void	aixioc_halt(curstat_t *);
