@@ -1,7 +1,7 @@
 /*
  *   libdi - CD Audio Player Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -19,12 +19,13 @@
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #ifndef LINT
-static char *_libdi_c_ident_ = "@(#)libdi.c	7.36 01/08/01";
+static char *_libdi_c_ident_ = "@(#)libdi.c	7.77 02/04/11";
 #endif
 
 #include "common_d/appenv.h"
 #include "common_d/patchlevel.h"
 #include "common_d/util.h"
+#include "cdda_d/cdda.h"
 #include "libdi_d/libdi.h"
 #include "libdi_d/scsipt.h"
 #include "libdi_d/slioc.h"
@@ -216,6 +217,16 @@ di_prncfg(void)
 		       app_data.devlist);
 	(void) fprintf(errfp, "\tdeviceInterfaceMethod:\t\t%d\n",
 		       app_data.di_method);
+	(void) fprintf(errfp, "\tcddaMethod:\t\t\t%d\n",
+		       app_data.cdda_method);
+	(void) fprintf(errfp, "\tcddaReadMethod:\t\t\t%d\n",
+		       app_data.cdda_rdmethod);
+	(void) fprintf(errfp, "\tcddaWriteMethod:\t\t%d\n",
+		       app_data.cdda_wrmethod);
+	(void) fprintf(errfp, "\tcddaScsiDensity:\t\t%d\n",
+		       app_data.cdda_scsidensity);
+	(void) fprintf(errfp, "\tcddaScsiReadCommand:\t\t%d\n",
+		       app_data.cdda_scsireadcmd);
 	(void) fprintf(errfp, "\tdriveVendorCode:\t\t%d\n",
 		       app_data.vendor_code);
 	(void) fprintf(errfp, "\tscsiVersionCheck:\t\t%s\n",
@@ -242,6 +253,8 @@ di_prncfg(void)
 		       di_boolstr(app_data.eject_supp));
 	(void) fprintf(errfp, "\tmodeSenseSetDBD:\t\t%s\n",
 		       di_boolstr(app_data.msen_dbd));
+	(void) fprintf(errfp, "\tmodeSenseUse10Byte:\t\t%s\n",
+		       di_boolstr(app_data.msen_10));
 	(void) fprintf(errfp, "\tvolumeControlSupport:\t\t%s\n",
 		       di_boolstr(app_data.mselvol_supp));
 	(void) fprintf(errfp, "\tbalanceControlSupport:\t\t%s\n",
@@ -268,10 +281,18 @@ di_prncfg(void)
 		       app_data.drv_blksz);
 	(void) fprintf(errfp, "\tspinUpInterval:\t\t\t%d\n",
 		       app_data.spinup_interval);
+	(void) fprintf(errfp, "\tcddaScsiModeSelect:\t\t%s\n",
+		       di_boolstr(app_data.cdda_modesel));
+	(void) fprintf(errfp, "\tcddaDataBigEndian:\t\t%s\n",
+		       di_boolstr(app_data.cdda_bigendian));
+	(void) fprintf(errfp, "\tcddaReadChunkBlocks:\t\t%d\n",
+		       app_data.cdda_readchkblks);
 
 	(void) fprintf(errfp,
 		       "\nDevice-specific (user-modifiable) parameters:\n");
 
+	(void) fprintf(errfp, "\tplayMode:\t\t\t%d\n",
+		       app_data.play_mode);
 	(void) fprintf(errfp, "\tvolumeControlTaper:\t\t%d\n",
 		       app_data.vol_taper);
 	(void) fprintf(errfp, "\tchannelRoute:\t\t\t%d\n",
@@ -302,6 +323,12 @@ di_prncfg(void)
 		       di_boolstr(app_data.multi_play));
 	(void) fprintf(errfp, "\treversePlay:\t\t\t%s\n",
 		       di_boolstr(app_data.reverse));
+	(void) fprintf(errfp, "\tcddaJitterCorrection:\t\t%s\n",
+		       di_boolstr(app_data.cdda_jitter_corr));
+	(void) fprintf(errfp, "\tcddaFilePerTrack:\t\t%s\n",
+		       di_boolstr(app_data.cdda_trkfile));
+	(void) fprintf(errfp, "\tcddaFileFormat:\t\t\t%d\n",
+		       app_data.cdda_filefmt);
 
 	(void) fprintf(errfp, "\n");
 }
@@ -450,6 +477,7 @@ di_init(di_client_t *clp)
 
 #if defined(DI_SCSIPT) && defined(DEMO_ONLY)
 	app_data.di_method = DI_SCSIPT;
+	app_data.cdda_method = 0;	/* CDDA_NONE */
 #else
 	/* Sanity check */
 	if (app_data.di_method < 0 || app_data.di_method >= MAX_METHODS) {
@@ -491,6 +519,41 @@ di_init(di_client_t *clp)
 		DI_FATAL(app_data.str_nomethod);
 		return;
 	}
+
+	/* Fill in device capabilities bitmask return */
+	clp->capab = (cdda_capab() | CAPAB_PLAYAUDIO);
+}
+
+
+/*
+ * di_playmode
+ *	Init/halt the CDDA mode
+ *
+ * Args:
+ *	s - Pointer to the curstat_t structure
+ *
+ * Return:
+ *	TRUE - success
+ *	FALSE - failure
+ */
+bool_t
+di_playmode(curstat_t *s)
+{
+	switch (s->mode) {
+	case MOD_STOP:
+	case MOD_NODISC:
+	case MOD_BUSY:
+		break;
+	default:
+		/* Stop playback first before changing mode */
+		di_stop(s, TRUE);
+		break;
+	}
+
+	if (ditbl[app_data.di_method].playmode != NULL)
+		return (ditbl[app_data.di_method].playmode(s));
+
+	return FALSE;
 }
 
 
@@ -904,6 +967,42 @@ di_mute_off(curstat_t *s)
 }
 
 
+/*
+ * di_cddajitter
+ *	CDDA jitter correction setting change notification function
+ *
+ * Args:
+ *	s - Pointer to the curstat_t structure
+ *
+ * Return:
+ *	Nothing.
+ */
+void
+di_cddajitter(curstat_t *s)
+{
+	if (ditbl[app_data.di_method].cddajitter != NULL)
+		ditbl[app_data.di_method].cddajitter(s);
+}
+
+
+/*
+ * di_debug
+ *	Debug level change notification function
+ *
+ * Args:
+ *	None.
+ *
+ * Return:
+ *	Nothing.
+ */
+void
+di_debug(void)
+{
+	if (ditbl[app_data.di_method].debug != NULL)
+		ditbl[app_data.di_method].debug();
+}
+
+
 /*
  * di_start
  *	Start the SCSI pass-through module.
@@ -1023,7 +1122,7 @@ di_dump_curstat(curstat_t *s)
 	(void) fprintf(errfp, "playorder=");
 	for (i = 0; i < (int) s->prog_tot; i++)
 		(void) fprintf(errfp, "%d ",
-			s->trkinfo[s->playorder[i]].trkno);
+			s->trkinfo[s->trkinfo[i].playorder].trkno);
 	(void) fprintf(errfp, "\n");
 
 	(void) fprintf(errfp,
@@ -1039,6 +1138,9 @@ di_dump_curstat(curstat_t *s)
 	(void) fprintf(errfp,
 		"vendor=\"%-8s\" prod=\"%-16s\" revnum=\"%-4s\"\n",
 		s->vendor, s->prod, s->revnum);
+	(void) fprintf(errfp, "outf_tmpl=%s pipeprog=%s\n",
+		s->outf_tmpl == NULL ? "NULL" : s->outf_tmpl,
+		s->pipeprog == NULL ? "NULL" : s->pipeprog);
 
 	(void) fprintf(errfp, "\nDevice registry: %s\n",
 		di_reghead == NULL ? "NULL" : "");
@@ -1709,6 +1811,28 @@ di_devspec_parmload(char *path, bool_t priv)
 				app_data.di_method = atoi(parm);
 				continue;
 			}
+			if (sscanf(buf, "cddaMethod: %s\n", parm) > 0) {
+				app_data.cdda_method = atoi(parm);
+				continue;
+			}
+			if (sscanf(buf, "cddaReadMethod: %s\n", parm) > 0) {
+				app_data.cdda_rdmethod = atoi(parm);
+				continue;
+			}
+			if (sscanf(buf, "cddaWriteMethod: %s\n", parm) > 0) {
+				app_data.cdda_wrmethod = atoi(parm);
+				continue;
+			}
+			if (sscanf(buf, "cddaScsiDensity: %s\n",
+				   parm) > 0) {
+				app_data.cdda_scsidensity = atoi(parm);
+				continue;
+			}
+			if (sscanf(buf, "cddaScsiReadCommand: %s\n",
+				   parm) > 0) {
+				app_data.cdda_scsireadcmd = atoi(parm);
+				continue;
+			}
 			if (sscanf(buf, "driveVendorCode: %s\n",
 				   parm) > 0) {
 				app_data.vendor_code = atoi(parm);
@@ -1773,6 +1897,11 @@ di_devspec_parmload(char *path, bool_t priv)
 				app_data.msen_dbd = util_stob(parm);
 				continue;
 			}
+			if (sscanf(buf, "modeSenseUse10Byte: %s\n",
+				   parm) > 0) {
+				app_data.msen_10 = util_stob(parm);
+				continue;
+			}
 			if (sscanf(buf, "volumeControlSupport: %s\n",
 				   parm) > 0) {
 				app_data.mselvol_supp = util_stob(parm);
@@ -1836,11 +1965,29 @@ di_devspec_parmload(char *path, bool_t priv)
 				app_data.spinup_interval = atoi(parm);
 				continue;
 			}
+			if (sscanf(buf, "cddaScsiModeSelect: %s\n",
+				   parm) > 0) {
+				app_data.cdda_modesel = util_stob(parm);
+				continue;
+			}
+			if (sscanf(buf, "cddaDataBigEndian: %s\n", parm) > 0) {
+				app_data.cdda_bigendian = util_stob(parm);
+				continue;
+			}
+			if (sscanf(buf, "cddaReadChunkBlocks: %s\n",
+				   parm) > 0) {
+				app_data.cdda_readchkblks = atoi(parm);
+				continue;
+			}
 		}
 
 		/* These are general parameters that can be
 		 * changed by the user.
 		 */
+		if (sscanf(buf, "playMode: %s\n", parm) > 0) {
+			app_data.play_mode = atoi(parm);
+			continue;
+		}
 		if (sscanf(buf, "volumeControlTaper: %s\n", parm) > 0) {
 			app_data.vol_taper = atoi(parm);
 			continue;
@@ -1925,6 +2072,18 @@ di_devspec_parmload(char *path, bool_t priv)
 			app_data.reverse = util_stob(parm);
 			continue;
 		}
+		if (sscanf(buf, "cddaJitterCorrection: %s\n", parm) > 0) {
+			app_data.cdda_jitter_corr = util_stob(parm);
+			continue;
+		}
+		if (sscanf(buf, "cddaFilePerTrack: %s\n", parm) > 0) {
+			app_data.cdda_trkfile = util_stob(parm);
+			continue;
+		}
+		if (sscanf(buf, "cddaFileFormat: %s\n", parm) > 0) {
+			app_data.cdda_filefmt = atoi(parm);
+			continue;
+		}
 	}
 
 	MEM_FREE(buf);
@@ -1992,7 +2151,7 @@ di_devspec_parmload(char *path, bool_t priv)
 		 */
 		if (!app_data.mselvol_supp) {
 			app_data.balance_supp = FALSE;
-			app_data.vol_taper = 0;
+			app_data.vol_taper = VOLTAPER_LINEAR;
 		}
 
 		/* If the drive does not support channel routing,
@@ -2017,6 +2176,13 @@ di_devspec_parmload(char *path, bool_t priv)
 		if (app_data.drv_blksz == 0 ||
 		    (app_data.drv_blksz % 512) != 0)
 			app_data.drv_blksz = STD_CDROM_BLKSZ;
+
+		if (app_data.play_mode == 0)
+			app_data.play_mode = PLAYMODE_STD;
+
+		if (app_data.cdda_readchkblks < MIN_CDDA_CHUNK_BLKS ||
+		    app_data.cdda_readchkblks > MAX_CDDA_CHUNK_BLKS)
+			app_data.cdda_readchkblks = DEF_CDDA_CHUNK_BLKS;
 	}
 }
 
@@ -2119,6 +2285,14 @@ di_devspec_parmsave(char *path)
 		       "file for details about the parameters.");
 
 	/* Write only user-changeable parameters */
+	(void) fprintf(fp, "playMode:\t\t%d\n",
+		       app_data.play_mode);
+	(void) fprintf(fp, "cddaJitterCorrection:\t%s\n",
+		       app_data.cdda_jitter_corr ? truestr : falsestr);
+	(void) fprintf(fp, "cddaFilePerTrack:\t%s\n",
+		       app_data.cdda_trkfile ? truestr : falsestr);
+	(void) fprintf(fp, "cddaFileFormat:\t\t%d\n",
+		       app_data.cdda_filefmt);
 	(void) fprintf(fp, "volumeControlTaper:\t%d\n",
 		       app_data.vol_taper);
 	(void) fprintf(fp, "channelRoute:\t\t%d\n",
@@ -2345,13 +2519,14 @@ di_devunlock(curstat_t *s)
  * Args:
  *	fd - The device file descriptor
  *	path - The device path name
+ *	flags - platform-specific flags
  *
  * Return:
  *	TRUE - success
  *	FALSE - failure
  */
 bool_t
-di_devreg(int fd, char *path)
+di_devreg(int fd, char *path, word32_t flags)
 {
 	di_devreg_t	*rp;
 
@@ -2374,6 +2549,7 @@ di_devreg(int fd, char *path)
 	}
 
 	rp->fd = fd;
+	rp->flags = flags;
 	rp->next = di_reghead;
 	di_reghead = rp;
 	DBGPRN(DBG_DEVIO)(errfp, "\nRegistered %s\n", path);
@@ -2417,10 +2593,38 @@ di_devunreg(int fd)
 }
 
 
+/*
+ * di_devgetent
+ *	Search the device registry and return a pointer to the
+ *	entry corresponding to that specified file descriptor.
+ *
+ * Args:
+ *	fd - The device file descriptor.
+ *
+ * Return:
+ *	Pointer to the di_devreg_t entry, or NULL if not found.
+ */
+di_devreg_t *
+di_devgetent(int fd)
+{
+	static di_devreg_t	*rp = NULL;
+
+	if (rp != NULL && rp->fd == fd)
+		return (rp);
+
+	for (rp = di_reghead; rp != NULL; rp = rp->next) {
+		if (rp->fd == fd)
+			break;
+	}
+
+	return (rp);
+}
+
+
 /*
  * di_devgetpath
  *	Search the device path registry and return the path name
- *	string corresponding to the specified file descriptor.
+ *	string corresponding to that specified file descriptor.
  *
  * Args:
  *	fd - The device file descriptor.
@@ -2538,7 +2742,7 @@ di_curtrk_pos(curstat_t *s)
 int
 di_curprog_pos(curstat_t *s)
 {
-	return ((int) s->playorder[s->prog_cnt]);
+	return ((int) s->trkinfo[s->prog_cnt].playorder);
 }
 
 
@@ -2590,7 +2794,11 @@ di_reset_curstat(curstat_t *s, bool_t clear_toc, bool_t eject)
 			s->trkinfo[i].frame = 0;
 			s->trkinfo[i].addr = 0;
 			s->trkinfo[i].type = TYP_AUDIO;
-			s->playorder[i] = -1;
+			s->trkinfo[i].playorder = -1;
+			if (s->trkinfo[i].outfile != NULL) {
+				MEM_FREE(s->trkinfo[i].outfile);
+				s->trkinfo[i].outfile = NULL;
+			}
 		}
 	}
 
@@ -2645,14 +2853,14 @@ di_reset_shuffle(curstat_t *s)
 	n = 0;
 	for (i = 0; i < (int) s->tot_trks; i++) {
 		if (s->trkinfo[i].type == TYP_AUDIO)
-			s->playorder[n++] = i;
+			s->trkinfo[n++].playorder = i;
 	}
 
 	s->prog_tot = (byte_t) n;
 
 	/* Initialize rest of list */
 	for (; n < MAXTRACK; n++)
-		s->playorder[n] = -1;
+		s->trkinfo[n].playorder = -1;
 
 	/*
 	 * Now shuffle the playlist by swapping random pairs:
@@ -2662,9 +2870,9 @@ di_reset_shuffle(curstat_t *s)
 	for (i = (int) s->prog_tot - 1; i > 0; i--) {
 		j = rand() % (i + 1);
 		if (j != i) {
-			x = s->playorder[i];
-			s->playorder[i] = s->playorder[j];
-			s->playorder[j] = x;
+			x = s->trkinfo[i].playorder;
+			s->trkinfo[i].playorder = s->trkinfo[j].playorder;
+			s->trkinfo[j].playorder = x;
 		}
 	}
 
@@ -2673,117 +2881,13 @@ di_reset_shuffle(curstat_t *s)
 
 		for (i = 0; i < (int) s->prog_tot; i++)
 			(void) fprintf(errfp, "%d ",
-				       s->trkinfo[s->playorder[i]].trkno);
+				   s->trkinfo[s->trkinfo[i].playorder].trkno);
 
 		(void) fprintf(errfp, "\n");
 	}
 }
 
 
-/*
- * di_taper_vol
- *	Translate the volume level based on the configured taper
- *	characteristics.
- *
- * Args:
- *	v - The linear volume value.
- *
- * Return:
- *	The curved volume value.
- */
-int
-di_taper_vol(int v)
-{
-	switch (app_data.vol_taper) {
-	case 1:
-		/* squared taper */
-		return (SQR(v) / MAX_VOL);
-	case 2:
-		/* inverse-squared taper */
-		return (MAX_VOL - (SQR(MAX_VOL - v) / MAX_VOL));
-	case 0:
-	default:
-		/* linear taper */
-		return (v);
-	}
-	/*NOTREACHED*/
-}
-
-
-/*
- * di_untaper_vol
- *	Translate the volume level based on the configured taper
- *	characteristics.
- *
- * Args:
- *	v - The curved volume value.
- *
- * Return:
- *	The linear volume value.
- */
-int
-di_untaper_vol(int v)
-{
-	switch (app_data.vol_taper) {
-	case 1:
-		/* squared taper */
-		return (util_isqrt(v) * 10);
-	case 2:
-		/* inverse-squared taper */
-		return (MAX_VOL - util_isqrt(SQR(MAX_VOL) - (MAX_VOL * v)));
-	case 0:
-	default:
-		/* linear taper */
-		return (v);
-	}
-	/*NOTREACHED*/
-}
-
-
-/*
- * di_scale_vol
- *	Scale logical audio volume value (0-100) to an 8-bit value
- *	(0-0xff) range.
- *
- * Args:
- *	v - The logical volume value
- *
- * Return:
- *	The scaled volume value
- */
-int
-di_scale_vol(int v)
-{
-	/* Convert logical audio volume value to 8-bit volume */
-	return ((v * (0xff - app_data.base_scsivol) / MAX_VOL) +
-	        app_data.base_scsivol);
-}
-
-
-/*
- * di_unscale_vol
- *	Scale an 8-bit audio volume parameter value (0-0xff) to the
- *	logical volume value (0-100).
- *
- * Args:
- *	v - The 8-bit volume value
- *
- * Return:
- *	The logical volume value
- */
-int
-di_unscale_vol(int v)
-{
-	register int	val;
-
-	/* Convert 8-bit audio volume value to logical volume */
-	val = (v - app_data.base_scsivol) * MAX_VOL /
-	      (0xff - app_data.base_scsivol);
-
-	return ((val < 0) ? 0 : val);
-}
-
-
 /*
  * di_xlate_blk
  *	Translate the CD-ROM drive's native LBA/length into an
