@@ -1,7 +1,7 @@
 /*
  *   libdi - scsipt SCSI Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@
  *   used here for identification purposes only.
  */
 #ifndef LINT
-static char *_os_aix_c_ident_ = "@(#)os_aix.c	6.35 01/04/17";
+static char *_os_aix_c_ident_ = "@(#)os_aix.c	6.37 02/03/17";
 #endif
 
 #include "common_d/appenv.h"
@@ -210,7 +210,7 @@ pthru_open(char *path)
 		return -1;
 	}
 
-	(void) di_devreg(fd, path);
+	(void) di_devreg(fd, path, 0);
 
 	/* AIX hack:  The CD-ROM driver allows the open to succeed
 	 * even if there is no CD loaded.  We test for the existence of
