@@ -1,7 +1,7 @@
 /*
  *   libdi - scsipt SCSI Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -35,10 +35,12 @@
 #ifndef __OS_AIX_H__
 #define __OS_AIX_H__
 
-#if defined(_AIX) && defined(DI_SCSIPT) && !defined(DEMO_ONLY)
+#if defined(_AIX) && \
+    (defined(DI_SCSIPT) || defined(CDDA_RD_SCSIPT)) && \
+    !defined(DEMO_ONLY)
 
 #ifndef LINT
-static char *_os_aix_h_ident_ = "@(#)os_aix.h	6.14 01/04/09";
+static char *_os_aix_h_ident_ = "@(#)os_aix.h	6.16 02/03/15";
 #endif
 
 #include <sys/cdrom.h>
@@ -55,7 +57,7 @@ extern int	pthru_open(char *);
 extern void	pthru_close(int);
 extern char	*pthru_vers(void);
 
-#endif	/* _AIX DI_SCSIPT DEMO_ONLY */
+#endif	/* _AIX DI_SCSIPT CDDA_RD_SCSIPT DEMO_ONLY */
 
 #endif	/* __OS_AIX_H__ */
 
