@@ -1,7 +1,7 @@
 /*
  *   libdi - scsipt SCSI Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -31,10 +31,12 @@
 #ifndef __OS_AUX_H__
 #define __OS_AUX_H__
 
-#if defined(macII) && defined(DI_SCSIPT) && !defined(DEMO_ONLY)
+#if defined(macII) && \
+    (defined(DI_SCSIPT) || defined(CDDA_RD_SCSIPT)) && \
+    !defined(DEMO_ONLY)
 
 #ifndef LINT
-static char *_os_aux_h_ident_ = "@(#)os_aux.h	6.14 01/04/09";
+static char *_os_aux_h_ident_ = "@(#)os_aux.h	6.16 02/03/15";
 #endif
 
 
@@ -74,7 +76,7 @@ extern int	pthru_open(char *);
 extern void	pthru_close(int);
 extern char	*pthru_vers(void);
 
-#endif	/* macII DI_SCSIPT DEMO_ONLY */
+#endif	/* macII DI_SCSIPT CDDA_RD_SCSIPT DEMO_ONLY */
 
 #endif	/* __OS_AUX_H__ */
 
