@@ -1,7 +1,7 @@
 /*
  *   libdi - scsipt SCSI Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -32,10 +32,12 @@
 #ifndef __OS_BSDI_H__
 #define __OS_BSDI_H__
 
-#if defined(__bsdi__) && defined(DI_SCSIPT) && !defined(DEMO_ONLY)
+#if defined(__bsdi__) && \
+    (defined(DI_SCSIPT) || defined(CDDA_RD_SCSIPT)) && \
+    !defined(DEMO_ONLY)
 
 #ifndef LINT
-static char *_os_bsdi_h_ident_ = "@(#)os_bsdi.h	6.16 01/04/09";
+static char *_os_bsdi_h_ident_ = "@(#)os_bsdi.h	6.18 02/03/15";
 #endif
 
 #include <dev/scsi/scsi.h>
@@ -58,7 +60,7 @@ extern int	pthru_open(char *);
 extern void	pthru_close(int);
 extern char	*pthru_vers(void);
 
-#endif	/* __bsdi__ DI_SCSIPT DEMO_ONLY */
+#endif	/* __bsdi__ DI_SCSIPT CDDA_RD_SCSIPT DEMO_ONLY */
 
 #endif	/* __OS_BSDI_H__ */
 
