@@ -1,7 +1,7 @@
 /*
  *   libdi - scsipt SCSI Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -21,10 +21,10 @@
 #ifndef __OS_CDSIM_H__
 #define __OS_CDSIM_H__
 
-#if defined(DI_SCSIPT) && defined(DEMO_ONLY)
+#if (defined(DI_SCSIPT) || defined(CDDA_RD_SCSIPT)) && defined(DEMO_ONLY)
 
 #ifndef LINT
-static char *_os_cdsim_h_ident_ = "@(#)os_cdsim.h	6.12 01/04/09";
+static char *_os_cdsim_h_ident_ = "@(#)os_cdsim.h	6.14 02/03/15";
 #endif
 
 
@@ -104,7 +104,7 @@ extern bool_t	cdsim_sendpkt(char *, int, simpkt_t *);
 extern bool_t	cdsim_getpkt(char *, int, simpkt_t *);
 extern void	cdsim_main(void);
 
-#endif	/* DI_SCSIPT DEMO_ONLY */
+#endif	/* DI_SCSIPT CDDA_RD_SCSIPT DEMO_ONLY */
 
 #endif	/* __OS_CDSIM_H__ */
 
