@@ -1,7 +1,7 @@
 /*
  *   libdi - scsipt SCSI Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -34,7 +34,7 @@
  *   purposes only.
  */
 #ifndef LINT
-static char *_os_dec_c_ident_ = "@(#)os_dec.c	6.41 01/04/17";
+static char *_os_dec_c_ident_ = "@(#)os_dec.c	6.43 02/03/17";
 #endif
 
 #include "common_d/appenv.h"
@@ -281,7 +281,7 @@ pthru_open(char *path)
 			if ((fd = open(DEV_CAM, O_RDWR, 0)) >= 0 ||
 			    (fd = open(DEV_CAM, O_RDONLY, 0)) >= 0) {
 
-				(void) di_devreg(fd, path);
+				(void) di_devreg(fd, path, 0);
 
 				/* Hack:  The CAM driver allows
 				 * the open to succeed even if there
