@@ -1,7 +1,7 @@
 /*
  *   libdi - scsipt SCSI Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -21,10 +21,10 @@
 #ifndef __OS_DEMO_H__
 #define __OS_DEMO_H__
 
-#if defined(DI_SCSIPT) && defined(DEMO_ONLY)
+#if (defined(DI_SCSIPT) || defined(CDDA_RD_SCSIPT)) && defined(DEMO_ONLY)
 
 #ifndef LINT
-static char *_os_demo_h_ident_ = "@(#)os_demo.h	6.17 01/04/09";
+static char *_os_demo_h_ident_ = "@(#)os_demo.h	6.19 02/03/15";
 #endif
 
 
@@ -40,7 +40,7 @@ extern char	*pthru_vers(void);
 extern bool_t	pthru_cdsim_start(void);
 extern void	pthru_cdsim_stop(void);
 
-#endif	/* DI_SCSIPT DEMO_ONLY */
+#endif	/* DI_SCSIPT CDDA_RD_SCSIPT DEMO_ONLY */
 
 #endif	/* __OS_DEMO_H__ */
 
