@@ -1,7 +1,7 @@
 /*
  *   libdi - scsipt SCSI Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -44,7 +44,7 @@
  *   when compiled with -DFREEBSD_CAM.
  */
 #ifndef LINT
-static char *_os_fnbsd_c_ident_ = "@(#)os_fnbsd.c	6.42 01/04/17";
+static char *_os_fnbsd_c_ident_ = "@(#)os_fnbsd.c	6.44 02/03/17";
 #endif
 
 #include "common_d/appenv.h"
@@ -297,7 +297,7 @@ pthru_open(char *path)
 	cp->prev = NULL;
 	cam_devlist_head = cp;
 
-	(void) di_devreg(cp->cam_dev->fd, path);
+	(void) di_devreg(cp->cam_dev->fd, path, 0);
 	return (cp->cam_dev->fd);
 #else
 	/* SCIOCCOMMAND ioctl method */
@@ -323,7 +323,7 @@ pthru_open(char *path)
 		return -1;
 	}
 
-	(void) di_devreg(fd, path);
+	(void) di_devreg(fd, path, 0);
 	return (fd);
 #endif	/* FREEBSD_CAM */
 }
