@@ -1,7 +1,7 @@
 /*
  *   libdi - scsipt SCSI Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -47,10 +47,11 @@
 #define __OS_FNBSD_H__
 
 #if (defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)) && \
-    defined(DI_SCSIPT) && !defined(DEMO_ONLY)
+    (defined(DI_SCSIPT) || defined(CDDA_RD_SCSIPT)) && \
+    !defined(DEMO_ONLY)
 
 #ifndef LINT
-static char *_os_fnbsd_h_ident_ = "@(#)os_fnbsd.h	6.20 01/04/09";
+static char *_os_fnbsd_h_ident_ = "@(#)os_fnbsd.h	6.22 02/03/15";
 #endif
 
 #ifdef FREEBSD_CAM
@@ -73,7 +74,9 @@ extern int	pthru_open(char *);
 extern void	pthru_close(int);
 extern char	*pthru_vers(void);
 
-#endif	/* __FreeBSD__ __NetBSD__ __OpenBSD__ DI_SCSIPT DEMO_ONLY */
+#endif	/* __FreeBSD__ __NetBSD__ __OpenBSD__
+	 * DI_SCSIPT CDDA_RD_SCSIPT DEMO_ONLY
+	 */
 
 #endif	/* __OS_FNBSD_H__ */
 
