@@ -1,7 +1,7 @@
 /*
  *   libdi - scsipt SCSI Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -32,7 +32,7 @@
  *   only.
  */
 #ifndef LINT
-static char *_os_hpux_c_ident_ = "@(#)os_hpux.c	6.41 01/04/17";
+static char *_os_hpux_c_ident_ = "@(#)os_hpux.c	6.43 02/03/17";
 #endif
 
 #include "common_d/appenv.h"
@@ -298,7 +298,7 @@ pthru_open(char *path)
 #endif	/* HPUX_EXCLUSIVE_OPEN */
 #endif	/* __hp9000s300 */
 
-	(void) di_devreg(fd, path);
+	(void) di_devreg(fd, path, 0);
 
 	/* HP-UX hack:  The CD-ROM driver allows the open to succeed
 	 * even if there is no CD loaded.  We test for the existence of
