@@ -1,7 +1,7 @@
 /*
  *   libdi - scsipt SCSI Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -30,10 +30,12 @@
 #ifndef __OS_HPUX_H__
 #define __OS_HPUX_H__
 
-#if defined(__hpux) && defined(DI_SCSIPT) && !defined(DEMO_ONLY)
+#if defined(__hpux) && \
+    (defined(DI_SCSIPT) || defined(CDDA_RD_SCSIPT)) && \
+    !defined(DEMO_ONLY)
 
 #ifndef LINT
-static char *_os_hpux_h_ident_ = "@(#)os_hpux.h	6.15 01/04/09";
+static char *_os_hpux_h_ident_ = "@(#)os_hpux.h	6.17 02/03/15";
 #endif
 
 #include <sys/utsname.h>
@@ -51,7 +53,7 @@ extern int	pthru_open(char *);
 extern void	pthru_close(int);
 extern char	*pthru_vers(void);
 
-#endif	/* __hpux DI_SCSIPT DEMO_ONLY */
+#endif	/* __hpux DI_SCSIPT CDDA_RD_SCSIPT DEMO_ONLY */
 
 #endif	/* __OS_HPUX_H__ */
 
