@@ -1,7 +1,7 @@
 /*
  *   libdi - scsipt SCSI Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -30,7 +30,7 @@
  *   and "NEWS-OS" are used here for identification purposes only.
  */
 #ifndef LINT
-static char *_os_news_c_ident_ = "@(#)os_news.c	6.29 01/04/17";
+static char *_os_news_c_ident_ = "@(#)os_news.c	6.31 02/03/17";
 #endif
 
 #include "common_d/appenv.h"
@@ -166,7 +166,7 @@ pthru_open(char *path)
 		return -1;
 	}
 
-	(void) di_devreg(fd, path);
+	(void) di_devreg(fd, path, 0);
 
 	return (fd);
 }
