@@ -1,7 +1,7 @@
 /*
  *   libdi - scsipt SCSI Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #ifndef LINT
-static char *_os_svr4_c_ident_ = "@(#)os_svr4.c	6.43 01/04/17";
+static char *_os_svr4_c_ident_ = "@(#)os_svr4.c	6.45 02/03/17";
 #endif
 
 #include "common_d/appenv.h"
@@ -259,7 +259,7 @@ pthru_open(char *path)
 		return -1;
 	}
 
-	(void) di_devreg(fd, path);
+	(void) di_devreg(fd, path, 0);
 	return (fd);
 }
 
@@ -511,7 +511,7 @@ pthru_open(char *path)
 		return -1;
 	}
 
-	(void) di_devreg(fd, path);
+	(void) di_devreg(fd, path, 0);
 
 	/* Motorola hack:  The CD-ROM driver allows the open to succeed
 	 * even if there is no CD loaded.  We test for the existence of
