@@ -1,7 +1,7 @@
 /*
  *   libdi - CD Audio Player Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -21,10 +21,10 @@
 #ifndef __SCSIPT_H__
 #define __SCSIPT_H__
 
-#ifdef DI_SCSIPT
+#if defined(DI_SCSIPT) || defined(CDDA_RD_SCSIPT)
 
 #ifndef LINT
-static char *_scsipt_h_ident_ = "@(#)scsipt.h	6.39 01/04/17";
+static char *_scsipt_h_ident_ = "@(#)scsipt.h	6.56 02/04/26";
 #endif
 
 
@@ -73,6 +73,7 @@ static char *_scsipt_h_ident_ = "@(#)scsipt.h	6.39 01/04/17";
 #define OP_S_TEST		0x00	/* test unit ready */
 #define OP_S_REZERO		0x01	/* rezero */
 #define OP_S_RSENSE		0x03	/* request sense */
+#define OP_S_READ		0x08	/* read (8) */
 #define OP_S_SEEK		0x0b	/* seek */
 #define OP_S_INQUIR		0x12	/* inquiry */
 #define OP_S_MSELECT		0x15	/* mode select (6) */
@@ -83,6 +84,7 @@ static char *_scsipt_h_ident_ = "@(#)scsipt.h	6.39 01/04/17";
 
 /* 10-byte commands */
 #define OP_M_RDCAP		0x25	/* read capacity */
+#define OP_M_READ		0x28	/* read (10) */
 #define OP_M_RDSUBQ		0x42	/* read subchannel */
 #define OP_M_RDTOC		0x43	/* read TOC */
 #define OP_M_RDHDR		0x44	/* read header */
@@ -91,12 +93,16 @@ static char *_scsipt_h_ident_ = "@(#)scsipt.h	6.39 01/04/17";
 #define OP_M_PLAYTI		0x48	/* play audio track/index */
 #define OP_M_PLAYTR		0x49	/* play audio track relative (10) */
 #define OP_M_PAUSE		0x4b	/* pause/resume */
+#define OP_M_MSELECT		0x55	/* mode select (10) */
+#define OP_M_MSENSE		0x5a	/* mode sense (10) */
 
 /* 12-byte commands */
 #define OP_L_PLAY		0xa5	/* play audio (12) */
+#define OP_L_READ		0xa8	/* read (12) */
 #define OP_L_PLAYTR		0xa9	/* play audio track relative (12) */
 #define OP_L_MOVEMED		0xa5	/* move medium */
 #define OP_L_READELEMSTAT	0xb8	/* read element status */
+#define OP_L_READCD		0xbe	/* MMC read CD */
 
 
 /* Data buffer lengths */
@@ -105,9 +111,9 @@ static char *_scsipt_h_ident_ = "@(#)scsipt.h	6.39 01/04/17";
 #define SZ_TOCHDR		4	/* TOC header size */
 #define SZ_TOCENT		8	/* TOC per-track entry size */
 #define SZ_MSENSE		60	/* max mode sense/mode sel data size */
-#define SZ_AUDIOCTL		20	/* audio control header+page size */
-#define SZ_DEVCAPAB		20	/* device capab header+page size */
-#define SZ_ELEMADDR		24	/* element addr header+page size */
+#define SZ_AUDIOCTL		16	/* audio control page size */
+#define SZ_DEVCAPAB		16	/* device capab page size */
+#define SZ_ELEMADDR		20	/* element addr page size */
 #define SZ_RSENSE		18	/* max request sense data size */
 #define SZ_ELEMHDR		8	/* med chgr element status header */
 #define SZ_ELEMSTAT		8	/* med chgr element status */
@@ -144,6 +150,13 @@ static char *_scsipt_h_ident_ = "@(#)scsipt.h	6.39 01/04/17";
 #define SCSICDB_RESET(p)	(void) memset(p, 0, MAX_CMDLEN);
 
 
+/* CDDA-over-SCSI read method code */
+#define CDDA_MMC		0	/* Use MMC read command */
+#define CDDA_STD		1	/* Use SCSI read command */
+#define CDDA_NEC		2	/* Use NEC vendor-unique */
+#define CDDA_SONY		3	/* Use Sony vendor-unique */
+
+
 /*
  * SCSI inquiry data
  */
@@ -175,8 +188,8 @@ typedef struct inqry_data {
  * Mode Sense/Mode Select data
  */
 
-/* Mode Sense/Mode Select data */
-typedef struct mode_sense_data {
+/* Mode Sense/Mode Select (6 byte) data */
+typedef struct mode_sense_6_data {
 	/* mode header */
 	unsigned int	data_len:8;	/* data length */
 	unsigned int	medium:8;	/* medium */
@@ -192,7 +205,29 @@ typedef struct mode_sense_data {
 	unsigned int	bdescr_len:8;	/* block descriptor length */
 
 	byte_t		data[48];	/* block desc/page desc data */
-} mode_sense_data_t;
+} mode_sense_6_data_t;
+
+
+/* Mode Sense/Mode Select (10 byte) data */
+typedef struct mode_sense_10_data {
+	/* mode header */
+	unsigned int	data_len:16;	/* data length */
+	unsigned int	medium:8;	/* medium */
+#if _BYTE_ORDER_ == _L_ENDIAN_
+	unsigned int	speed:4;	/* speed */
+	unsigned int	buffered:3;	/* buffered */
+	unsigned int	wprot:1;	/* write protected */
+#else	/* _BYTE_ORDER_ == _B_ENDIAN_ */
+	unsigned int	wprot:1;	/* write protected */
+	unsigned int	buffered:3;	/* buffered */
+	unsigned int	speed:4;	/* speed */
+#endif	/* _BYTE_ORDER_ */
+
+	unsigned int	res:16;		/* reserved */
+	unsigned int	bdescr_len:16;	/* block descriptor length */
+
+	byte_t		data[48];	/* block desc/page desc data */
+} mode_sense_10_data_t;
 
 
 /* Block descriptor data */
@@ -754,58 +789,6 @@ typedef struct {
 } mcparm_t;
 
 
-/*
- * Vendor-unique module initialization jump table
- */
-typedef struct {
-	void		(*init)(void);	/* VU init function */
-} vuinit_tbl_t;
-
-
-/*
- * Vendor-unique module entry jump table
- */
-typedef struct {
-	/* Vendor name string */
-	char		*vendor;
-
-	/* Play audio function */
-	bool_t		(*playaudio)(byte_t, word32_t, word32_t,
-				     msf_t *, msf_t *, byte_t, byte_t);
-
-	/* Pause/resume function */
-	bool_t		(*pause_resume)(bool_t);
-
-	/* Start/stop function */
-	bool_t		(*start_stop)(bool_t, bool_t);
-
-	/* Playback status function */
-	bool_t		(*get_playstatus)(curstat_t *, byte_t *);
-
-	/* Playback volume function */
-	int		(*volume)(int, curstat_t *, bool_t);
-
-	/* Channel routing function */
-	bool_t		(*route)(curstat_t *);
-
-	/* Playback mute function */
-	bool_t		(*mute)(bool_t);
-
-	/* Read TOC function */
-	bool_t		(*get_toc)(curstat_t *);
-
-	/* Eject function */
-	bool_t		(*eject)(void);
-
-	/* Module start function */
-	void		(*start)(void);
-
-	/* Module halt function */
-	void		(*halt)(void);
-} vu_tbl_t;
-
-
-
 /***** Additional include files *****/
 
 /* OS interface library headers */
@@ -867,11 +850,88 @@ typedef struct {
 #include "libdi_d/vu_sony.h"		/* Sony vendor-unique header */
 #include "libdi_d/vu_tosh.h"		/* Toshiba vendor-unique header */
 
+/*
+ * Functions for vendor-unique module use only
+ */
+extern bool_t	scsipt_rezero_unit(int);
+extern bool_t	scsipt_request_sense(int, byte_t *, int);
+extern bool_t	scsipt_rdsubq(int, cdstat_t *);
+extern bool_t	scsipt_modesense(int, byte_t *, byte_t, byte_t, int);
+extern bool_t	scsipt_modesel(int, byte_t *, byte_t, int);
+extern bool_t	scsipt_inquiry(int, byte_t *, int);
+extern bool_t	scsipt_rdtoc(int, byte_t *, int, bool_t);
+extern bool_t	scsipt_playmsf(int, msf_t *, msf_t *);
+extern bool_t	scsipt_play10(int, word32_t, word32_t);
+extern bool_t	scsipt_play12(int, word32_t, word32_t);
+extern bool_t	scsipt_play_trkidx(int, int, int, int, int);
+extern bool_t	scsipt_prev_allow(int, bool_t);
+extern bool_t	scsipt_start_stop(int, bool_t, bool_t, bool_t);
+extern bool_t	scsipt_pause_resume(int, bool_t);
+extern bool_t	scsipt_move_medium(int, word16_t, word16_t, word16_t);
+extern bool_t	scsipt_init_elemstat(int);
+extern bool_t	scsipt_read_elemstat(int, byte_t *, int, int);
+extern bool_t	scsipt_disc_present(int);
+
+#endif	/* DI_SCSIPT CDDA_RD_SCSIPT */
+
+#ifdef DI_SCSIPT
+
+/*
+ * Vendor-unique module initialization jump table
+ */
+typedef struct {
+	void		(*init)(void);	/* VU init function */
+} vuinit_tbl_t;
+
+
+/*
+ * Vendor-unique module entry jump table
+ */
+typedef struct {
+	/* Vendor name string */
+	char		*vendor;
+
+	/* Play audio function */
+	bool_t		(*playaudio)(byte_t, word32_t, word32_t,
+				     msf_t *, msf_t *, byte_t, byte_t);
+
+	/* Pause/resume function */
+	bool_t		(*pause_resume)(bool_t);
+
+	/* Start/stop function */
+	bool_t		(*start_stop)(bool_t, bool_t);
+
+	/* Playback status function */
+	bool_t		(*get_playstatus)(cdstat_t *);
+
+	/* Playback volume function */
+	int		(*volume)(int, curstat_t *, bool_t);
+
+	/* Channel routing function */
+	bool_t		(*route)(curstat_t *);
+
+	/* Playback mute function */
+	bool_t		(*mute)(bool_t);
+
+	/* Read TOC function */
+	bool_t		(*get_toc)(curstat_t *);
+
+	/* Eject function */
+	bool_t		(*eject)(void);
+
+	/* Module start function */
+	void		(*start)(void);
+
+	/* Module halt function */
+	void		(*halt)(void);
+} vu_tbl_t;
+
 
 /*
  * Public functions
  */
 extern void	scsipt_init(curstat_t *, di_tbl_t *);
+extern bool_t	scsipt_playmode(curstat_t *);
 extern bool_t	scsipt_check_disc(curstat_t *);
 extern void	scsipt_status_upd(curstat_t *);
 extern void	scsipt_lock(curstat_t *, bool_t);
@@ -894,39 +954,18 @@ extern void	scsipt_warp(curstat_t *);
 extern void	scsipt_route(curstat_t *);
 extern void	scsipt_mute_on(curstat_t *);
 extern void	scsipt_mute_off(curstat_t *);
+extern void	scsipt_cddajitter(curstat_t *);
+extern void	scsipt_debug(void);
 extern void	scsipt_start(curstat_t *);
 extern void	scsipt_icon(curstat_t *, bool_t);
 extern void	scsipt_halt(curstat_t *);
 extern char	*scsipt_methodstr(void);
 
-/*
- * Functions for vendor-unique module use only
- */
-extern bool_t	scsipt_rezero_unit(int);
-extern bool_t	scsipt_request_sense(int, byte_t *, int);
-extern bool_t	scsipt_rdsubq(int, byte_t *, byte_t, bool_t, int, bool_t);
-extern bool_t	scsipt_modesense(int, byte_t *, byte_t, byte_t, int);
-extern bool_t	scsipt_modesel(int, byte_t *, byte_t, int);
-extern bool_t	scsipt_inquiry(int, byte_t *, int);
-extern bool_t	scsipt_rdtoc(int, byte_t *, int, bool_t);
-extern bool_t	scsipt_playmsf(int, msf_t *, msf_t *);
-extern bool_t	scsipt_play10(int, word32_t, word32_t);
-extern bool_t	scsipt_play12(int, word32_t, word32_t);
-extern bool_t	scsipt_play_trkidx(int, int, int, int, int);
-extern bool_t	scsipt_prev_allow(int, bool_t);
-extern bool_t	scsipt_start_stop(int, bool_t, bool_t, bool_t);
-extern bool_t	scsipt_pause_resume(int, bool_t);
-extern bool_t	scsipt_move_medium(int, word16_t, word16_t, word16_t);
-extern bool_t	scsipt_init_elemstat(int);
-extern bool_t	scsipt_read_elemstat(int, byte_t *, int, int);
-extern bool_t	scsipt_disc_present(int);
-
-
 #else
 
 #define scsipt_init	NULL
 
-#endif
+#endif	/* DI_SCSIPT */
 
 #endif	/* __SCSIPT_H__ */
 
