@@ -1,7 +1,7 @@
 /*
  *   libdi - CD Audio Player Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -30,13 +30,14 @@
  */
 
 #ifndef LINT
-static char *_slioc_c_ident_ = "@(#)slioc.c	6.166 01/06/10";
+static char *_slioc_c_ident_ = "@(#)slioc.c	6.191 02/04/24";
 #endif
 
 #include "common_d/appenv.h"
 #include "common_d/util.h"
 #include "libdi_d/libdi.h"
 #include "libdi_d/slioc.h"
+#include "cdda_d/cdda.h"
 
 #if defined(DI_SLIOC) && !defined(DEMO_ONLY)
 
@@ -53,6 +54,7 @@ STATIC bool_t	slioc_pause_resume(bool_t),
 		slioc_disc_ready(curstat_t *),
 		slioc_disc_present(bool_t),
 		slioc_open(curstat_t *);
+STATIC int	slioc_cfg_vol(int, curstat_t *, bool_t);
 STATIC void	slioc_stat_poll(curstat_t *),
 		slioc_insert_poll(curstat_t *),
 		slioc_close(void);
@@ -82,6 +84,7 @@ STATIC word32_t	slioc_sav_end_addr,		/* Err recov saved end addr */
 		slioc_next_sam;			/* Next SAMPLE track */
 STATIC msf_t	slioc_sav_end_msf;		/* Err recov saved end MSF */
 STATIC byte_t	slioc_sav_end_fmt;		/* Err recov saved end fmt */
+STATIC cdda_client_t slioc_cdda_client;		/* CDDA client struct */
 
 
 /* SunOS/Solaris/Linux CDROM ioctl names */
@@ -95,6 +98,9 @@ STATIC iocname_t iname[] = {
 	{ CDROMPAUSE,		"CDROMPAUSE"		},
 	{ CDROMRESUME,		"CDROMRESUME"		},
 	{ CDROMVOLCTRL,		"CDROMVOLCTRL"		},
+#ifdef CDROMVOLREAD
+	{ CDROMVOLREAD,		"CDROMVOLREAD"		},
+#endif
 	{ CDROMPLAYTRKIND,	"CDROMPLAYTRKIND"	},
 	{ CDROMPLAYMSF,		"CDROMPLAYMSF"		},
 #ifdef CDROMLOAD
@@ -533,25 +539,115 @@ slioc_close(void)
  *	Send Read Subchannel command to the device
  *
  * Args:
- *	buf - Pointer to the return data buffer
- *	msf - Whether to use MSF or logical block address data format
+ *	sp  - Pointer to the caller-supplied cdstat_t return structure
  *
  * Return:
  *	TRUE - success
  *	FALSE - failure
  */
 STATIC bool_t
-slioc_rdsubq(struct cdrom_subchnl *sub, bool_t msf)
+slioc_rdsubq(cdstat_t *sp)
 {
-	bool_t	ret;
+	struct cdrom_subchnl	sub;
+	bool_t			ret;
 
-	sub->cdsc_format = msf ? CDROM_MSF : CDROM_LBA;
-	ret = slioc_send(CDROMSUBCHNL, sub, sizeof(struct cdrom_subchnl),
+	(void) memset((byte_t *) &sub, 0, sizeof(struct cdrom_subchnl));
+
+	sub.cdsc_format = app_data.subq_lba ? CDROM_LBA : CDROM_MSF;
+	ret = slioc_send(CDROMSUBCHNL, &sub, sizeof(struct cdrom_subchnl),
 			 TRUE, NULL);
+	if (!ret)
+		return FALSE;
 
-	if (ret) {
-		DBGDUMP(DBG_DEVIO)("cdrom_subchnl data bytes", (byte_t *) sub,
-			sizeof(struct cdrom_subchnl));
+	DBGDUMP(DBG_DEVIO)("cdrom_subchnl data bytes", (byte_t *) &sub,
+		sizeof(struct cdrom_subchnl));
+
+	/* Hack: to work around firmware anomalies in some CD-ROM drives. */
+	if (sub.cdsc_trk >= MAXTRACK && sub.cdsc_trk != LEAD_OUT_TRACK) {
+		sp->status = CDSTAT_NOSTATUS;
+		return TRUE;
+	}
+
+	/* Map the subchannel data into cdstat_t form */
+
+	switch (sub.cdsc_audiostatus) {
+	case CDROM_AUDIO_PLAY:
+		sp->status = CDSTAT_PLAYING;
+		break;
+	case CDROM_AUDIO_PAUSED:
+		sp->status = CDSTAT_PAUSED;
+		break;
+	case CDROM_AUDIO_COMPLETED:
+		sp->status = CDSTAT_COMPLETED;
+		break;
+	case CDROM_AUDIO_ERROR:
+		sp->status = CDSTAT_FAILED;
+		break;
+	case CDROM_AUDIO_INVALID:
+	case CDROM_AUDIO_NO_STATUS:
+	default:
+		sp->status = CDSTAT_NOSTATUS;
+		break;
+	}
+
+	if (slioc_bcd_hack) {
+		/* Hack: BUGLY CD-ROM firmware */
+		sp->track = (int) util_bcdtol(sub.cdsc_trk);
+		sp->index = (int) util_bcdtol(sub.cdsc_ind);
+	}
+	else {
+		sp->track = (int) sub.cdsc_trk;
+		sp->index = (int) sub.cdsc_ind;
+	}
+
+	if (sub.cdsc_format == CDROM_LBA) {
+		/* LBA mode */
+		sp->abs_addr.addr = di_xlate_blk(sub.cdsc_absaddr.lba);
+		util_blktomsf(
+			sp->abs_addr.addr,
+			&sp->abs_addr.min,
+			&sp->abs_addr.sec,
+			&sp->abs_addr.frame,
+			MSF_OFFSET
+		);
+
+		sp->rel_addr.addr = di_xlate_blk(sub.cdsc_reladdr.lba);
+		util_blktomsf(
+			sp->rel_addr.addr,
+			&sp->rel_addr.min,
+			&sp->rel_addr.sec,
+			&sp->rel_addr.frame,
+#ifdef linux
+			/* Note: Linux pre-adjusts for MSF_OFFSET */
+			MSF_OFFSET
+#else
+			0
+#endif
+		);
+	}
+	else {
+		/* MSF mode */
+		sp->abs_addr.min = sub.cdsc_absaddr.msf.minute;
+		sp->abs_addr.sec = sub.cdsc_absaddr.msf.second;
+		sp->abs_addr.frame = sub.cdsc_absaddr.msf.frame;
+		util_msftoblk(
+			sp->abs_addr.min,
+			sp->abs_addr.sec,
+			sp->abs_addr.frame,
+			&sp->abs_addr.addr,
+			MSF_OFFSET
+		);
+
+		sp->rel_addr.min = sub.cdsc_reladdr.msf.minute;
+		sp->rel_addr.sec = sub.cdsc_reladdr.msf.second;
+		sp->rel_addr.frame = sub.cdsc_reladdr.msf.frame;
+		util_msftoblk(
+			sp->rel_addr.min,
+			sp->rel_addr.sec,
+			sp->rel_addr.frame,
+			&sp->rel_addr.addr,
+			0
+		);
 	}
 
 	return (ret);
@@ -932,7 +1028,8 @@ slioc_play_trkidx(int start_trk, int start_idx, int end_trk, int end_idx)
 STATIC bool_t
 slioc_start_stop(bool_t start, bool_t loej)
 {
-	bool_t	ret;
+	bool_t		ret;
+	curstat_t	*s = di_clinfo->curstat_addr();
 
 	if (app_data.strict_pause_resume && slioc_paused)
 		(void) slioc_pause_resume(TRUE);
@@ -954,6 +1051,9 @@ slioc_start_stop(bool_t start, bool_t loej)
 	else {
 		slioc_playing = FALSE;
 
+		if (PLAYMODE_IS_CDDA(app_data.play_mode))
+			(void) cdda_stop(slioc_fd, s);
+
 		if (loej)
 			ret = slioc_send(CDROMEJECT, NULL, 0, TRUE, NULL);
 		else
@@ -998,15 +1098,21 @@ slioc_start_stop(bool_t start, bool_t loej)
 STATIC bool_t
 slioc_pause_resume(bool_t resume)
 {
-	bool_t	ret;
+	bool_t		ret;
+	curstat_t	*s = di_clinfo->curstat_addr();
 
 	if (!app_data.pause_supp)
 		return FALSE;
 
-	ret = slioc_send(
-		resume ? CDROMRESUME : CDROMPAUSE,
-		NULL, 0, TRUE, NULL
-	);
+	if (PLAYMODE_IS_CDDA(app_data.play_mode)) {
+		ret = cdda_pause_resume(slioc_fd, s, resume);
+	}
+	else {
+		ret = slioc_send(
+			resume ? CDROMRESUME : CDROMPAUSE,
+			NULL, 0, TRUE, NULL
+		);
+	}
 	if (ret)
 		slioc_paused = !resume;
 
@@ -1050,7 +1156,10 @@ slioc_do_playaudio(
 			*emsfp = NULL;
 	bool_t		ret = FALSE,
 			do_playmsf,
+			do_play10,
+			do_play12,
 			do_playti;
+	curstat_t	*s = di_clinfo->curstat_addr();
 
 	/* Fix addresses: Some CD-ROM drives will only allow playing to
 	 * the last frame minus a few frames.
@@ -1092,6 +1201,8 @@ slioc_do_playaudio(
 	slioc_sav_end_fmt = addr_fmt;
 
 	do_playmsf = (addr_fmt & ADDR_MSF) && app_data.playmsf_supp;
+	do_play10 = (addr_fmt & ADDR_BLK) && app_data.play10_supp;
+	do_play12 = (addr_fmt & ADDR_BLK) && app_data.play12_supp;
 	do_playti = (addr_fmt & ADDR_TRKIDX) && app_data.playti_supp;
 
 	if (do_playmsf || do_playti) {
@@ -1113,11 +1224,36 @@ slioc_do_playaudio(
 		}
 	}
 
-	if (do_playmsf)
-		ret = slioc_playmsf(start_msf, emsfp);
-	
-	if (!ret && do_playti)
-		ret = slioc_play_trkidx(trk, idx, trk, idx);
+	if (PLAYMODE_IS_CDDA(app_data.play_mode)) {
+		if (do_play12 || do_play10) {
+			ret = cdda_play(slioc_fd, s, start_addr, end_addr);
+		}
+		else if (do_playmsf) {
+			util_msftoblk(
+				start_msf->min,
+				start_msf->sec,
+				start_msf->frame,
+				&start_addr,
+				MSF_OFFSET
+			);
+			util_msftoblk(
+				emsfp->min,
+				emsfp->sec,
+				emsfp->frame,
+				&end_addr,
+				MSF_OFFSET
+			);
+			
+			ret = cdda_play(slioc_fd, s, start_addr, end_addr);
+		}
+	}
+	else {
+		if (do_playmsf)
+			ret = slioc_playmsf(start_msf, emsfp);
+		
+		if (!ret && do_playti)
+			ret = slioc_play_trkidx(trk, idx, trk, idx);
+	}
 
 	if (ret) {
 		slioc_playing = TRUE;
@@ -1129,19 +1265,20 @@ slioc_do_playaudio(
 
 
 /*
- * slioc_fail_recov
- *	Playback error recovery handler: Restart playback after skipping
- *	some frames.
+ * slioc_play_recov
+ *	Playback interruption recovery handler: Restart playback after
+ *	skipping some frames.
  *
  * Args:
- *	blk - Fault frame address
+ *	blk   - Interruption frame address
+ *	iserr - Whether interruption is due to an error
  *
  * Return:
  *	TRUE - success
  *	FALSE - failure
  */
 STATIC bool_t
-slioc_fail_recov(word32_t blk)
+slioc_play_recov(word32_t blk, bool_t iserr)
 {
 	msf_t		recov_start_msf;
 	word32_t	recov_start_addr;
@@ -1178,11 +1315,15 @@ slioc_fail_recov(word32_t blk)
 
 	if (ret) {
 		/* Restart playback */
-		(void) fprintf(errfp, "CD audio: %s (%02u:%02u.%02u)\n",
+		if (iserr) {
+			(void) fprintf(errfp,
+				"CD audio: %s (%02u:%02u.%02u)\n",
 				app_data.str_recoverr,
 				recov_start_msf.min,
 				recov_start_msf.sec,
-				recov_start_msf.frame);
+				recov_start_msf.frame
+			);
+		}
 
 		ret = slioc_do_playaudio(
 			slioc_sav_end_fmt,
@@ -1210,11 +1351,11 @@ slioc_fail_recov(word32_t blk)
 STATIC bool_t
 slioc_get_playstatus(curstat_t *s)
 {
-	struct cdrom_subchnl	sub;
+	cdstat_t		cdstat;
 	word32_t		curtrk,
 				curidx;
-	byte_t			audio_status;
-	bool_t			done;
+	bool_t			ret,
+				done;
 	static int		errcnt = 0,
 				nostatcnt = 0;
 	static word32_t		errblk = 0;
@@ -1227,8 +1368,31 @@ slioc_get_playstatus(curstat_t *s)
 
 	in_slioc_get_playstatus = TRUE;
 
-	(void) memset((byte_t *) &sub, 0, sizeof(struct cdrom_subchnl));
-	if (!slioc_rdsubq(&sub, (bool_t) !app_data.subq_lba)) {
+	if (PLAYMODE_IS_CDDA(app_data.play_mode)) {
+		ret = cdda_getstatus(slioc_fd, s, &cdstat);
+		if (ret &&
+		    (cdstat.level != s->level ||
+		     cdstat.level_left  != s->level_left ||
+		     cdstat.level_right != s->level_right)) {
+			int	vol;
+
+			/* Update volume & balance level */
+			s->level_left = cdstat.level_left;
+			s->level_right = cdstat.level_right;
+			vol = slioc_cfg_vol((int) cdstat.level, s, FALSE);
+			if (vol >= 0) {
+				s->level = vol;
+				SET_VOL_SLIDER(s->level);
+				SET_BAL_SLIDER((int)
+					(s->level_right - s->level_left) / 2
+				);
+			}
+		}
+	}
+	else
+		ret = slioc_rdsubq(&cdstat);
+		
+	if (!ret) {
 		/* Check to see if the disc had been manually ejected */
 		if (!slioc_disc_ready(s)) {
 			slioc_sav_end_addr = 0;
@@ -1243,116 +1407,56 @@ slioc_get_playstatus(curstat_t *s)
 			return FALSE;
 		}
 
-		/* The read subchannel command failed for some
-		 * unknown reason.  Just return success and
-		 * hope the next poll succeeds.  We don't want
-		 * to return FALSE here because that would stop
-		 * the poll.
+		/* Can't get playback status for some unknown reason.
+		 * Just return success and hope the next poll succeeds.
+		 * We don't want to return FALSE here because that would
+		 * stop the poll.
 		 */
 		in_slioc_get_playstatus = FALSE;
 		return TRUE;
 	}
 
-	/* Check the subchannel data */
-
-	if (sub.cdsc_format == CDROM_LBA) {
-		/* LBA mode */
-		s->curpos_tot.addr = di_xlate_blk(sub.cdsc_absaddr.lba);
-		util_blktomsf(
-			s->curpos_tot.addr,
-			&s->curpos_tot.min,
-			&s->curpos_tot.sec,
-			&s->curpos_tot.frame,
-			MSF_OFFSET
-		);
-
-		s->curpos_trk.addr = di_xlate_blk(sub.cdsc_reladdr.lba);
-		util_blktomsf(
-			s->curpos_trk.addr,
-			&s->curpos_trk.min,
-			&s->curpos_trk.sec,
-			&s->curpos_trk.frame,
-#ifdef linux
-			/* Note: Linux pre-adjusts for MSF_OFFSET */
-			MSF_OFFSET
-#else
-			0
-#endif
-		);
-	}
-	else {
-		/* MSF mode */
-		s->curpos_tot.frame = sub.cdsc_absaddr.msf.frame;
-		s->curpos_tot.sec = sub.cdsc_absaddr.msf.second;
-		s->curpos_tot.min = sub.cdsc_absaddr.msf.minute;
-		util_msftoblk(
-			s->curpos_tot.min,
-			s->curpos_tot.sec,
-			s->curpos_tot.frame,
-			&s->curpos_tot.addr,
-			MSF_OFFSET
-		);
-
-		s->curpos_trk.frame = sub.cdsc_reladdr.msf.frame;
-		s->curpos_trk.sec = sub.cdsc_reladdr.msf.second;
-		s->curpos_trk.min = sub.cdsc_reladdr.msf.minute;
-		util_msftoblk(
-			s->curpos_trk.min,
-			s->curpos_trk.sec,
-			s->curpos_trk.frame,
-			&s->curpos_trk.addr,
-			0
-		);
-	}
+	curtrk = cdstat.track;
+	curidx = cdstat.index;
+	s->curpos_tot = cdstat.abs_addr;	/* structure copy */
+	s->curpos_trk = cdstat.rel_addr;	/* structure copy */
 
 	/* Update time display */
 	DPY_TIME(s, FALSE);
 
-	if (slioc_bcd_hack) {
-		/* Hack: BUGLY CD-ROM firmware */
-		curtrk = util_bcdtol(sub.cdsc_trk);
-		curidx = util_bcdtol(sub.cdsc_ind);
-	}
-	else {
-		curtrk = sub.cdsc_trk;
-		curidx = sub.cdsc_ind;
-	}
-	/* Hack: to work around firmware anomalies
-	 * in some CD-ROM drives.
-	 */
-	if (curtrk >= MAXTRACK && curtrk != CDROM_LEADOUT)
-		audio_status = CDROM_AUDIO_INVALID;
-
 	if (curtrk != s->cur_trk) {
 		s->cur_trk = curtrk;
+		/* Update track number display */
 		DPY_TRACK(s);
 	}
 
 	if (curidx != s->cur_idx) {
 		s->cur_idx = curidx;
 		s->sav_iaddr = s->curpos_tot.addr;
+		/* Update index number display */
 		DPY_INDEX(s);
 	}
 
-	audio_status = sub.cdsc_audiostatus;
+	/* Update play mode display */
+	DPY_PLAYMODE(s, FALSE);
 
 	/* Hack: to work around the fact that some CD-ROM drives
 	 * return CDROM_AUDIO_PAUSED status after issuing a Stop Unit command.
 	 * Just treat the status as completed if we get a paused status
 	 * and we don't expect the drive to be paused.
 	 */
-	if (audio_status == CDROM_AUDIO_PAUSED && s->mode != MOD_PAUSE &&
+	if (cdstat.status == CDSTAT_PAUSED && s->mode != MOD_PAUSE &&
 	    !slioc_idx_pause)
-		audio_status = CDROM_AUDIO_COMPLETED;
+		cdstat.status = CDSTAT_COMPLETED;
 
 	/* Force completion status */
 	if (slioc_fake_stop)
-		audio_status = CDROM_AUDIO_COMPLETED;
+		cdstat.status = CDSTAT_COMPLETED;
 
 	/* Deal with playback status */
-	switch (audio_status) {
-	case CDROM_AUDIO_PLAY:
-	case CDROM_AUDIO_PAUSED:
+	switch (cdstat.status) {
+	case CDSTAT_PLAYING:
+	case CDSTAT_PAUSED:
 		nostatcnt = 0;
 		done = FALSE;
 
@@ -1364,7 +1468,7 @@ slioc_get_playstatus(curstat_t *s)
 			errcnt = 0;
 		break;
 
-	case CDROM_AUDIO_ERROR:
+	case CDSTAT_FAILED:
 		nostatcnt = 0;
 		/* Check to see if the disc had been manually ejected */
 		if (!slioc_disc_ready(s)) {
@@ -1396,19 +1500,17 @@ slioc_get_playstatus(curstat_t *s)
 
 		errblk = s->curpos_tot.addr;
 
-		if (!done && slioc_fail_recov(errblk)) {
+		if (!done && slioc_play_recov(errblk, TRUE)) {
 			in_slioc_get_playstatus = FALSE;
 			return TRUE;
 		}
 
 		/*FALLTHROUGH*/
 
-	case CDROM_AUDIO_COMPLETED:
-	case CDROM_AUDIO_NO_STATUS:
-	case CDROM_AUDIO_INVALID:
+	case CDSTAT_COMPLETED:
+	case CDSTAT_NOSTATUS:
 	default:
-		if (audio_status == CDROM_AUDIO_NO_STATUS &&
-		    nostatcnt++ < 20) {
+		if (cdstat.status == CDSTAT_NOSTATUS && nostatcnt++ < 20) {
 			/* Allow 20 occurrences of nostatus, then stop */
 			done = FALSE;
 			break;
@@ -1563,21 +1665,63 @@ slioc_get_playstatus(curstat_t *s)
 STATIC int
 slioc_cfg_vol(int vol, curstat_t *s, bool_t query)
 {
+#ifdef CDROMVOLREAD
+	int			vol1,
+				vol2;
+#endif
 	struct cdrom_volctrl	volctrl;
 	static bool_t		first = TRUE;
 
 	if (!app_data.mselvol_supp)
 		return 0;
 
+	if (PLAYMODE_IS_CDDA(app_data.play_mode))
+		return (cdda_vol(slioc_fd, s, vol, query));
+
 	(void) memset((byte_t *) &volctrl, 0, sizeof(struct cdrom_volctrl));
 
 	if (query) {
 		if (first) {
 			first = FALSE;
 
-			/* SunOS/Solaris/Linux doesn't give a way to read
-			 * volume setting via CDROM ioctl.
-			 * Force the setting to maximum.
+#ifdef CDROMVOLREAD
+			/* Try using the CDROMVOLREAD ioctl */
+			if (slioc_send(CDROMVOLREAD, &volctrl,
+					sizeof(struct cdrom_volctrl),
+					FALSE, NULL)) {
+				DBGDUMP(DBG_DEVIO)("cdrom_volctrl data bytes",
+					(byte_t *) &volctrl,
+					sizeof(struct cdrom_volctrl));
+				vol1 = util_untaper_vol(
+				    util_unscale_vol((int) volctrl.channel0)
+				);
+				vol2 = util_untaper_vol(
+				    util_unscale_vol((int) volctrl.channel2)
+				);
+
+				if (vol1 == vol2) {
+					s->level_left = s->level_right = 100;
+					vol = vol1;
+				}
+				else if (vol1 > vol2) {
+					s->level_left = 100;
+					s->level_right =
+						(byte_t)((vol2 * 100) / vol1);
+					vol = vol1;
+				}
+				else {
+					s->level_left =
+						(byte_t) ((vol1 * 100) / vol2);
+					s->level_right = 100;
+					vol = vol2;
+				}
+
+				return (vol);
+			}
+#endif	/* CDROMVOLREAD */
+
+			/* There is no way to read volume setting via
+			 * CDROM ioctl.  Force the setting to maximum.
 			 */
 			vol = 100;
 			s->level_left = s->level_right = 100;
@@ -1587,11 +1731,11 @@ slioc_cfg_vol(int vol, curstat_t *s, bool_t query)
 		return (vol);
 	}
 	else {
-		volctrl.channel0 = di_scale_vol(
-			di_taper_vol(vol * (int) s->level_left / 100)
+		volctrl.channel0 = util_scale_vol(
+			util_taper_vol(vol * (int) s->level_left / 100)
 		);
-		volctrl.channel1 = di_scale_vol(
-			di_taper_vol(vol * (int) s->level_right / 100)
+		volctrl.channel1 = util_scale_vol(
+			util_taper_vol(vol * (int) s->level_right / 100)
 		);
 
 		DBGDUMP(DBG_DEVIO)("cdrom_volctrl data bytes",
@@ -1606,7 +1750,7 @@ slioc_cfg_vol(int vol, curstat_t *s, bool_t query)
 			 * and retry.
 			 */
 			volctrl.channel0 = volctrl.channel1 =
-				di_scale_vol(di_taper_vol(vol));
+				util_scale_vol(util_taper_vol(vol));
 
 			DBGDUMP(DBG_DEVIO)("cdrom_volctrl data bytes",
 				(byte_t *) &volctrl,
@@ -1623,7 +1767,6 @@ slioc_cfg_vol(int vol, curstat_t *s, bool_t query)
 
 			/* Still failed: just drop through */
 		}
-
 	}
 
 	return -1;
@@ -2051,7 +2194,7 @@ slioc_disc_ready(curstat_t *s)
 	if (!err) {
 		if (first_open) {
 			/* Let things settle a bit */
-			sleep(1);
+			(void) sleep(1);
 
 			/* Fill in inquiry data */
 			slioc_vendor_model(s);
@@ -2537,7 +2680,8 @@ slioc_run_prog(curstat_t *s)
 		/* Do not allow a program that contains only data tracks */
 		hasaudio = FALSE;
 		for (i = 0; i < (int) s->prog_tot; i++) {
-			if (s->trkinfo[s->playorder[i]].type == TYP_AUDIO) {
+			if (s->trkinfo[s->trkinfo[i].playorder].type ==
+			    TYP_AUDIO) {
 				hasaudio = TRUE;
 				break;
 			}
@@ -2701,6 +2845,7 @@ slioc_init(curstat_t *s, di_tbl_t *dt)
 		return;
 
 	/* Initialize libdi calling table */
+	dt->playmode = slioc_playmode;
 	dt->check_disc = slioc_check_disc;
 	dt->status_upd = slioc_status_upd;
 	dt->lock = slioc_lock;
@@ -2720,9 +2865,11 @@ slioc_init(curstat_t *s, di_tbl_t *dt)
 	dt->rew = slioc_rew;
 	dt->ff = slioc_ff;
 	dt->warp = slioc_warp;
-	dt->route = NULL;
+	dt->route = slioc_route;
 	dt->mute_on = slioc_mute_on;
 	dt->mute_off = slioc_mute_off;
+	dt->cddajitter = slioc_cddajitter;
+	dt->debug = slioc_debug;
 	dt->start = slioc_start;
 	dt->icon = slioc_icon;
 	dt->halt = slioc_halt;
@@ -2731,7 +2878,6 @@ slioc_init(curstat_t *s, di_tbl_t *dt)
 	/* Hardwire some unsupported features */
 	app_data.caddylock_supp = FALSE;
 	app_data.caddy_lock = FALSE;
-	app_data.chroute_supp = FALSE;
 
 	/* Initalize SunOS/Solaris/Linux ioctl method */
 	slioc_stat_polling = FALSE;
@@ -2787,6 +2933,49 @@ slioc_init(curstat_t *s, di_tbl_t *dt)
 }
 
 
+/*
+ * slioc_playmode
+ *	Init/halt CDDA mode
+ *
+ * Args:
+ *	s - Pointer to the curstat_t structure
+ *
+ * Return:
+ *	TRUE - success
+ *	FALSE - failure
+ */
+bool_t
+slioc_playmode(curstat_t *s)
+{
+	bool_t		ret,
+			cdda;
+	static bool_t	prev_cdda = FALSE;
+
+	cdda = (bool_t) PLAYMODE_IS_CDDA(app_data.play_mode);
+
+	if (cdda == prev_cdda)
+		return TRUE;	/* No change */
+
+	if (cdda) {
+		slioc_cdda_client.curstat_addr = di_clinfo->curstat_addr;
+		slioc_cdda_client.fatal_msg = di_clinfo->fatal_msg;
+		slioc_cdda_client.warning_msg = di_clinfo->warning_msg;
+		slioc_cdda_client.info_msg = di_clinfo->info_msg;
+
+		ret = cdda_init(s, &slioc_cdda_client);
+	}
+	else {
+		cdda_halt(slioc_fd, s);
+		ret = TRUE;
+	}
+
+	if (ret)
+		prev_cdda = cdda;
+
+	return (ret);
+}
+
+
 /*
  * slioc_check_disc
  *	Check if disc is ready for use
@@ -2949,7 +3138,7 @@ slioc_load_eject(curstat_t *s)
 		for (i = 0; i < 3; i++) {
 			if ((ret = slioc_disc_ready(s)) == TRUE)
 				break;
-			sleep(1);
+			(void) sleep(1);
 		}
 
 		if (ret || !app_data.eject_supp)
@@ -4253,7 +4442,7 @@ slioc_ff(curstat_t *s, bool_t start)
 					s->bp_endpos_tot.addr) {
 				/* No more left to play */
 				/* Restore volume */
-				scsipt_mute_off(s);
+				slioc_mute_off(s);
 				return;
 			}
 			else {
@@ -4407,6 +4596,28 @@ slioc_warp(curstat_t *s)
 }
 
 
+/*
+ * slioc_route
+ *	Channel routing function
+ *
+ * Args:
+ *	s - Pointer to the curstat_t structure
+ *
+ * Return:
+ *	Nothing.
+ */
+void
+slioc_route(curstat_t *s)
+{
+	if (!app_data.chroute_supp)
+		return;
+
+	/* Only CDDA mode supports channel routing on Linux/SunOS */
+	if (PLAYMODE_IS_CDDA(app_data.play_mode))
+		(void) cdda_chroute(slioc_fd, s);
+}
+
+
 /*
  * slioc_mute_on
  *	Mute audio function
@@ -4441,6 +4652,85 @@ slioc_mute_off(curstat_t *s)
 }
 
 
+/*
+ * slioc_cddajitter
+ *	CDDA jitter correction setting change notification
+ *
+ * Args:
+ *	s - Pointer to the curstat_t structure
+ *
+ * Return:
+ *	Nothing.
+ */
+void
+slioc_cddajitter(curstat_t *s)
+{
+	word32_t	curblk = 0;
+	byte_t		omode;
+	
+	if (PLAYMODE_IS_CDDA(app_data.play_mode)) {
+		omode = s->mode;
+		if (omode == MOD_PAUSE)
+			omode = MOD_PLAY;
+
+		/* Save state */
+		switch (omode) {
+		case MOD_PLAY:
+		case MOD_SAMPLE:
+			curblk = s->curpos_tot.addr;
+			slioc_stop_stat_poll();
+			break;
+
+		default:
+			break;
+		}
+
+		/* Restart CDDA */
+		cdda_halt(slioc_fd, s);
+		(void) sleep(1);
+
+		slioc_cdda_client.curstat_addr = di_clinfo->curstat_addr;
+		slioc_cdda_client.fatal_msg = di_clinfo->fatal_msg;
+		slioc_cdda_client.warning_msg = di_clinfo->warning_msg;
+		slioc_cdda_client.info_msg = di_clinfo->info_msg;
+
+		(void) cdda_init(s, &slioc_cdda_client);
+
+		/* Restore old state */
+		switch (omode) {
+		case MOD_PLAY:
+		case MOD_SAMPLE:
+			if (slioc_play_recov(curblk, FALSE))
+				slioc_start_stat_poll(s);
+			break;
+
+		default:
+			break;
+		}
+
+		s->mode = omode;
+	}
+}
+
+
+/*
+ * slioc_debug
+ *	Debug level change notification
+ *
+ * Args:
+ *	None.
+ *
+ * Return:
+ *	Nothing.
+ */
+void
+slioc_debug(void)
+{
+	if (PLAYMODE_IS_CDDA(app_data.play_mode))
+		cdda_debug(app_data.debug);
+}
+
+
 /*
  * slioc_start
  *	Start the SunOS/Solaris/Linux ioctl method.
@@ -4548,6 +4838,9 @@ slioc_halt(curstat_t *s)
 			}
 		}
 	}
+	
+	/* Shut down CDDA */
+	cdda_halt(slioc_fd, s);
 
 	/* Close device */
 	DBGPRN(DBG_DEVIO)(errfp, "\nClose: %s\n", s->curdev);
