@@ -1,7 +1,7 @@
 /*
  *   libdi - CD Audio Player Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,7 @@
  *   for identification purposes only.
  */
 #ifndef LINT
-static char *_vu_nec_c_ident_ = "@(#)vu_nec.c	6.30 01/04/09";
+static char *_vu_nec_c_ident_ = "@(#)vu_nec.c	6.32 02/01/06";
 #endif
 
 #include "common_d/appenv.h"
@@ -188,20 +188,15 @@ nec_pause_resume(bool_t resume)
  *	status.
  *
  * Args:
- *	s - Pointer to the curstat_t structure
- *	audio_status - Address where a current status code (SCSI-2
- *		       style) is to be returned.
+ *	sp - Pointer to the caller-supplied cdstat_t return structure
  *
  * Return:
  *	TRUE - success
  *	FALSE - failure
  */
 bool_t
-nec_get_playstatus(curstat_t *s, byte_t *audio_status)
+nec_get_playstatus(cdstat_t *sp)
 {
-	int		i,
-			trkno,
-			idxno;
 	byte_t		buf[sizeof(nsubq_data_t)];
 	nsubq_data_t	*d;
 
@@ -220,50 +215,37 @@ nec_get_playstatus(curstat_t *s, byte_t *audio_status)
 
 	d = (nsubq_data_t *)(void *) buf;
 
-	trkno = util_bcdtol((word32_t) d->trkno);
-	if (s->cur_trk != trkno) {
-		s->cur_trk = trkno;
-		DPY_TRACK(s);
-	}
+	sp->track = (int) util_bcdtol((word32_t) d->trkno);
+	sp->index = (int) util_bcdtol((word32_t) d->idxno);
 
-	idxno = util_bcdtol((word32_t) d->idxno);
-	if (s->cur_idx != idxno) {
-		s->cur_idx = idxno;
-		s->sav_iaddr = s->curpos_tot.addr;
-		DPY_INDEX(s);
-	}
-
-	if ((i = di_curtrk_pos(s)) >= 0)
-		s->trkinfo[i].type = (d->trktype == 0) ? TYP_AUDIO : TYP_DATA;
-
-	s->curpos_tot.min = (byte_t) util_bcdtol(d->abs_min);
-	s->curpos_tot.sec = (byte_t) util_bcdtol(d->abs_sec);
-	s->curpos_tot.frame = (byte_t) util_bcdtol(d->abs_frame);
-	s->curpos_trk.min = (byte_t) util_bcdtol(d->rel_min);
-	s->curpos_trk.sec = (byte_t) util_bcdtol(d->rel_sec);
-	s->curpos_trk.frame = (byte_t) util_bcdtol(d->rel_frame);
+	sp->abs_addr.min = (byte_t) util_bcdtol(d->abs_min);
+	sp->abs_addr.sec = (byte_t) util_bcdtol(d->abs_sec);
+	sp->abs_addr.frame = (byte_t) util_bcdtol(d->abs_frame);
+	sp->rel_addr.min = (byte_t) util_bcdtol(d->rel_min);
+	sp->rel_addr.sec = (byte_t) util_bcdtol(d->rel_sec);
+	sp->rel_addr.frame = (byte_t) util_bcdtol(d->rel_frame);
 	util_msftoblk(
-		s->curpos_tot.min, s->curpos_tot.sec, s->curpos_tot.frame,
-		&s->curpos_tot.addr, MSF_OFFSET
+		sp->abs_addr.min, sp->abs_addr.sec, sp->abs_addr.frame,
+		&sp->abs_addr.addr, MSF_OFFSET
 	);
 	util_msftoblk(
-		s->curpos_trk.min, s->curpos_trk.sec, s->curpos_trk.frame,
-		&s->curpos_trk.addr, 0
+		sp->rel_addr.min, sp->rel_addr.sec, sp->rel_addr.frame,
+		&sp->rel_addr.addr, 0
 	);
 
 	/* Translate NEC audio status to SCSI-2 audio status */
 	switch (d->audio_status) {
 	case NAUD_PLAYING:
-		*audio_status = AUDIO_PLAYING;
+		sp->status = CDSTAT_PLAYING;
 		break;
 
 	case NAUD_PAUSED:
 	case NAUD_SRCH_PAUSED:
-		*audio_status = AUDIO_PAUSED;
+		sp->status = CDSTAT_PAUSED;
 		break;
 
 	case NAUD_COMPLETED:
-		*audio_status = AUDIO_COMPLETED;
+		sp->status = CDSTAT_COMPLETED;
 		break;
 	}
 
