@@ -1,7 +1,7 @@
 /*
  *   libdi - CD Audio Player Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -31,11 +31,13 @@
 #ifdef VENDOR_NEC
 
 #ifndef LINT
-static char *_vu_nec_h_ident_ = "@(#)vu_nec.h	6.12 01/04/09";
+static char *_vu_nec_h_ident_ = "@(#)vu_nec.h	6.15 02/03/15";
 #endif
 
 
 /* NEC vendor-unique commands */
+#define OP_VN_READCDDA		0xd4	/* NEC read CD-DA (10) */
+#define OP_VN_READCDDAMSF	0xd5	/* NEC read CD-DA MSF */
 #define OP_VN_AUDSRCH		0xd8	/* NEC audio search */
 #define OP_VN_AUDPLAY		0xd9	/* NEC play audio */
 #define OP_VN_STILL		0xda	/* NEC still */
@@ -113,7 +115,7 @@ typedef struct ninfo_02 {		/* specified track starting time */
 extern bool_t	nec_playaudio(byte_t, word32_t, word32_t, msf_t *, msf_t *,
 			byte_t, byte_t);
 extern bool_t	nec_pause_resume(bool_t);
-extern bool_t	nec_get_playstatus(curstat_t *, byte_t *);
+extern bool_t	nec_get_playstatus(cdstat_t *);
 extern bool_t	nec_get_toc(curstat_t *);
 extern bool_t	nec_mute(bool_t);
 extern bool_t	nec_eject(void);
