@@ -1,7 +1,7 @@
 /*
  *   libdi - CD Audio Player Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,7 @@
  *   Corporation, and is used here for identification purposes only.
  */
 #ifndef LINT
-static char *_vu_pana_c_ident_ = "@(#)vu_pana.c	6.30 01/04/09";
+static char *_vu_pana_c_ident_ = "@(#)vu_pana.c	6.34 02/03/17";
 #endif
 
 #include "common_d/appenv.h"
@@ -218,22 +218,19 @@ pana_pause_resume(bool_t resume)
  *	status.
  *
  * Args:
- *	s - Pointer to the curstat_t structure
- *	audio_status - Address where a current status code (SCSI-2
- *		       style) is to be returned.
+ *	sp - Pointer to the caller-supplied cdstat_t return structure
  *
  * Return:
  *	TRUE - success
  *	FALSE - failure
  */
 bool_t
-pana_get_playstatus(curstat_t *s, byte_t *audio_status)
+pana_get_playstatus(cdstat_t *sp)
 {
-	int		trkno,
-			idxno;
 	subq_hdr_t	*h;
 	subq_01_t	*p;
-	byte_t		dbuf[SZ_VM_RDSUBQ];
+	byte_t		dbuf[SZ_VM_RDSUBQ],
+			status;
 	static int	notvalid_cnt = 0;
 	static byte_t	prev_stat = AUDIO_NOTVALID;
 
@@ -270,43 +267,52 @@ pana_get_playstatus(curstat_t *s, byte_t *audio_status)
 		/* Allow up to MAX_NOTVAL consecutive occurances
 		 * of this anomaly.
 		 */
-		*audio_status = prev_stat;
+		status = prev_stat;
 		if (prev_stat != AUDIO_NOTVALID)
 			notvalid_cnt++;
 	}
 	else {
-		prev_stat = h->audio_status;
-		*audio_status = h->audio_status;
+		status = prev_stat = h->audio_status;
 		notvalid_cnt = 0;
 	}
 
-	trkno = (word32_t) p->trkno;
-	if (s->cur_trk != trkno) {
-		s->cur_trk = trkno;
-		DPY_TRACK(s);
+	switch (status) {
+	case AUDIO_PLAYING:
+		sp->status = CDSTAT_PLAYING;
+		break;
+	case AUDIO_PAUSED:
+		sp->status = CDSTAT_PAUSED;
+		break;
+	case AUDIO_COMPLETED:
+		sp->status = CDSTAT_COMPLETED;
+		break;
+	case AUDIO_FAILED:
+		sp->status = CDSTAT_FAILED;
+		break;
+	case AUDIO_NOTVALID:
+	case AUDIO_NOSTATUS:
+	default:
+		sp->status = CDSTAT_NOSTATUS;
+		break;
 	}
 
-	idxno = (word32_t) p->idxno;
-	if (s->cur_idx != idxno) {
-		s->cur_idx = idxno;
-		s->sav_iaddr = s->curpos_tot.addr;
-		DPY_INDEX(s);
-	}
+	sp->track = (int) p->trkno;
+	sp->index = (int) p->idxno;
 
-	s->curpos_tot.min = p->abs_addr.msf.min;
-	s->curpos_tot.sec = p->abs_addr.msf.sec;
-	s->curpos_tot.frame = p->abs_addr.msf.frame;
+	sp->abs_addr.min = p->abs_addr.msf.min;
+	sp->abs_addr.sec = p->abs_addr.msf.sec;
+	sp->abs_addr.frame = p->abs_addr.msf.frame;
 	util_msftoblk(
-		s->curpos_tot.min, s->curpos_tot.sec, s->curpos_tot.frame,
-		&s->curpos_tot.addr, MSF_OFFSET
+		sp->abs_addr.min, sp->abs_addr.sec, sp->abs_addr.frame,
+		&sp->abs_addr.addr, MSF_OFFSET
 	);
 
-	s->curpos_trk.min = p->rel_addr.msf.min;
-	s->curpos_trk.sec = p->rel_addr.msf.sec;
-	s->curpos_trk.frame = p->rel_addr.msf.frame;
+	sp->rel_addr.min = p->rel_addr.msf.min;
+	sp->rel_addr.sec = p->rel_addr.msf.sec;
+	sp->rel_addr.frame = p->rel_addr.msf.frame;
 	util_msftoblk(
-		s->curpos_trk.min, s->curpos_trk.sec, s->curpos_trk.frame,
-		&s->curpos_trk.addr, 0
+		sp->rel_addr.min, sp->rel_addr.sec, sp->rel_addr.frame,
+		&sp->rel_addr.addr, 0
 	);
 
 	return TRUE;
@@ -425,7 +431,7 @@ pana_volume(int vol, curstat_t *s, bool_t query)
 {
 	int			vol1,
 				vol2;
-	mode_sense_data_t	*ms_data;
+	mode_sense_6_data_t	*ms_data;
 	blk_desc_t		*bdesc;
 	audio_pg_t		*audiopg;
 	byte_t			buf[SZ_MSENSE];
@@ -438,17 +444,17 @@ pana_volume(int vol, curstat_t *s, bool_t query)
 	if (!scsipt_modesense(devfd, buf, 0, PG_VM_AUDCTL, SZ_VM_AUDCTL))
 		return -1;
 
-	ms_data = (mode_sense_data_t *)(void *) buf;
+	ms_data = (mode_sense_6_data_t *)(void *) buf;
 	bdesc = (blk_desc_t *)(void *) ms_data->data;
 	audiopg = (audio_pg_t *)(void *) &ms_data->data[ms_data->bdescr_len];
 
 	if (audiopg->pg_code == PG_VM_AUDCTL) {
 		if (query) {
-			vol1 = di_untaper_vol(
-				di_unscale_vol((int) audiopg->p0_vol)
+			vol1 = util_untaper_vol(
+				util_unscale_vol((int) audiopg->p0_vol)
 			);
-			vol2 = di_untaper_vol(
-				di_unscale_vol((int) audiopg->p1_vol)
+			vol2 = util_untaper_vol(
+				util_unscale_vol((int) audiopg->p1_vol)
 			);
 			pana_route_left = (byte_t) audiopg->p0_ch_ctrl;
 			pana_route_right = (byte_t) audiopg->p1_ch_ctrl;
@@ -475,11 +481,11 @@ pana_volume(int vol, curstat_t *s, bool_t query)
 			if (ms_data->bdescr_len > 0)
 				bdesc->num_blks = 0;
 
-			audiopg->p0_vol = di_scale_vol(
-				di_taper_vol(vol * (int) s->level_left / 100)
+			audiopg->p0_vol = util_scale_vol(
+			    util_taper_vol(vol * (int) s->level_left / 100)
 			);
-			audiopg->p1_vol = di_scale_vol(
-				di_taper_vol(vol * (int) s->level_right / 100)
+			audiopg->p1_vol = util_scale_vol(
+			    util_taper_vol(vol * (int) s->level_right / 100)
 			);
 
 			audiopg->p0_ch_ctrl = pana_route_left;
@@ -498,7 +504,7 @@ pana_volume(int vol, curstat_t *s, bool_t query)
 				 * and retry.
 				 */
 				audiopg->p0_vol = audiopg->p1_vol =
-					di_scale_vol(di_taper_vol(vol));
+					util_scale_vol(util_taper_vol(vol));
 
 				if (scsipt_modesel(devfd, buf, PG_VM_AUDCTL,
 						   SZ_VM_AUDCTL)) {
