@@ -1,7 +1,7 @@
 /*
  *   libdi - CD Audio Player Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,7 @@
  *   here for identification purposes only.
  */
 #ifndef LINT
-static char *_vu_sony_c_ident_ = "@(#)vu_sony.c	6.34 01/04/09";
+static char *_vu_sony_c_ident_ = "@(#)vu_sony.c	6.38 02/03/17";
 #endif
 
 #include "common_d/appenv.h"
@@ -211,20 +211,15 @@ sony_pause_resume(bool_t resume)
  *	status.
  *
  * Args:
- *	s - Pointer to the curstat_t structure
- *	audio_status - Address where a current status code (SCSI-2
- *		       style) is to be returned.
+ *	sp - Pointer to the caller-supplied cdstat_t return structure
  *
  * Return:
  *	TRUE - success
  *	FALSE - failure
  */
 bool_t
-sony_get_playstatus(curstat_t *s, byte_t *audio_status)
+sony_get_playstatus(cdstat_t *sp)
 {
-	int		i,
-			trkno,
-			idxno;
 	byte_t		dbuf[sizeof(sstat_data_t)],
 			qbuf[sizeof(ssubq_data_t)];
 	sstat_data_t	*d;
@@ -250,34 +245,30 @@ sony_get_playstatus(curstat_t *s, byte_t *audio_status)
 
 	d = (sstat_data_t *)(void *) dbuf;
 
-	/* Translate Sony audio status to SCSI-2 audio status */
+	/* Translate Sony audio status to cdstat_t status */
 	switch (d->audio_status) {
 	case SAUD_PLAYING:
 	case SAUD_MUTED:
-		*audio_status = AUDIO_PLAYING;
+		sp->status = CDSTAT_PLAYING;
 		break;
 
 	case SAUD_PAUSED:
-		*audio_status = AUDIO_PAUSED;
+		sp->status = CDSTAT_PAUSED;
 		break;
 
 	case SAUD_COMPLETED:
-		*audio_status = AUDIO_COMPLETED;
+		sp->status = CDSTAT_COMPLETED;
 		break;
 
 	case SAUD_ERROR:
-		*audio_status = AUDIO_FAILED;
+		sp->status = CDSTAT_FAILED;
 		break;
 
 	case SAUD_NOTREQ:
-		*audio_status = AUDIO_NOSTATUS;
+		sp->status = CDSTAT_NOSTATUS;
 		break;
 	}
 
-	if ((i = di_curtrk_pos(s)) >= 0)
-		s->trkinfo[i].type = (d->trktype == 0) ? TYP_AUDIO : TYP_DATA;
-
-
 	/*
 	 * Send Sony Read Subchannel command
 	 */
@@ -298,32 +289,22 @@ sony_get_playstatus(curstat_t *s, byte_t *audio_status)
 
 	q = (ssubq_data_t *)(void *) qbuf;
 
-	trkno = (word32_t) q->trkno;
-	if (s->cur_trk != trkno) {
-		s->cur_trk = trkno;
-		DPY_TRACK(s);
-	}
+	sp->track = (int) q->trkno;
+	sp->index = (int) q->idxno;
 
-	idxno = (word32_t) q->idxno;
-	if (s->cur_idx != idxno) {
-		s->cur_idx = idxno;
-		s->sav_iaddr = s->curpos_tot.addr;
-		DPY_INDEX(s);
-	}
-
-	s->curpos_tot.min = (byte_t) q->abs_min;
-	s->curpos_tot.sec = (byte_t) q->abs_sec;
-	s->curpos_tot.frame = (byte_t) q->abs_frame;
-	s->curpos_trk.min = (byte_t) q->rel_min;
-	s->curpos_trk.sec = (byte_t) q->rel_sec;
-	s->curpos_trk.frame = (byte_t) q->rel_frame;
+	sp->abs_addr.min = (byte_t) q->abs_min;
+	sp->abs_addr.sec = (byte_t) q->abs_sec;
+	sp->abs_addr.frame = (byte_t) q->abs_frame;
+	sp->rel_addr.min = (byte_t) q->rel_min;
+	sp->rel_addr.sec = (byte_t) q->rel_sec;
+	sp->rel_addr.frame = (byte_t) q->rel_frame;
 	util_msftoblk(
-		s->curpos_tot.min, s->curpos_tot.sec, s->curpos_tot.frame,
-		&s->curpos_tot.addr, MSF_OFFSET
+		sp->abs_addr.min, sp->abs_addr.sec, sp->abs_addr.frame,
+		&sp->abs_addr.addr, MSF_OFFSET
 	);
 	util_msftoblk(
-		s->curpos_trk.min, s->curpos_trk.sec, s->curpos_trk.frame,
-		&s->curpos_trk.addr, 0
+		sp->rel_addr.min, sp->rel_addr.sec, sp->rel_addr.frame,
+		&sp->rel_addr.addr, 0
 	);
 
 	return TRUE;
@@ -463,8 +444,8 @@ sony_volume(int vol, curstat_t *s, bool_t query)
 	d = (sstat_data_t *)(void *) buf;
 
 	if (query) {
-		vol1 = di_untaper_vol(di_unscale_vol((int) d->vol0));
-		vol2 = di_untaper_vol(di_unscale_vol((int) d->vol1));
+		vol1 = util_untaper_vol(util_unscale_vol((int) d->vol0));
+		vol2 = util_untaper_vol(util_unscale_vol((int) d->vol1));
 		sony_route_left = (byte_t) d->sel0;
 		sony_route_right = (byte_t) d->sel1;
 
@@ -488,11 +469,11 @@ sony_volume(int vol, curstat_t *s, bool_t query)
 	else {
 		(void) memset(buf, 0, 10);
 
-		d->vol0 = (byte_t) di_scale_vol(
-			di_taper_vol(vol * (int) s->level_left / 100)
+		d->vol0 = (byte_t) util_scale_vol(
+			util_taper_vol(vol * (int) s->level_left / 100)
 		);
-		d->vol1 = (byte_t) di_scale_vol(
-			di_taper_vol(vol * (int) s->level_right / 100)
+		d->vol1 = (byte_t) util_scale_vol(
+			util_taper_vol(vol * (int) s->level_right / 100)
 		);
 		d->sel0 = sony_route_left;
 		d->sel1 = sony_route_right;
@@ -513,7 +494,9 @@ sony_volume(int vol, curstat_t *s, bool_t query)
 			/* Set the balance to the center
 			 * and retry.
 			 */
-			d->vol0 = d->vol1 = di_scale_vol(di_taper_vol(vol));
+			d->vol0 = d->vol1 = util_scale_vol(
+				util_taper_vol(vol)
+			);
 
 			DBGDUMP(DBG_DEVIO)("sony: Playback Control data bytes",
 				buf, SZ_VS_PLAYSTAT);
@@ -619,7 +602,7 @@ void
 sony_start(void)
 {
 	byte_t			buf[SZ_VS_CDPARM];
-	mode_sense_data_t	*ms_data;
+	mode_sense_6_data_t	*ms_data;
 	blk_desc_t		*bdesc;
 	cdparm_pg_t		*parm_pg;
 
@@ -637,7 +620,7 @@ sony_start(void)
 				      SZ_VS_CDPARM))
 			return;		/* Error */
 
-		ms_data = (mode_sense_data_t *)(void *) buf;
+		ms_data = (mode_sense_6_data_t *)(void *) buf;
 		bdesc = (blk_desc_t *)(void *) ms_data->data;
 		parm_pg = (cdparm_pg_t *)(void *)
 			  &ms_data->data[ms_data->bdescr_len];
