@@ -1,7 +1,7 @@
 /*
  *   libdi - CD Audio Player Device Interface Library
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -31,7 +31,7 @@
 #ifdef VENDOR_TOSHIBA
 
 #ifndef LINT
-static char *_vu_tosh_h_ident_ = "@(#)vu_tosh.h	6.12 01/04/09";
+static char *_vu_tosh_h_ident_ = "@(#)vu_tosh.h	6.14 02/01/06";
 #endif
 
 
@@ -115,7 +115,7 @@ typedef struct tinfo_02 {		/* specified track starting time */
 extern bool_t	tosh_playaudio(byte_t, word32_t, word32_t, msf_t *, msf_t *,
 			byte_t, byte_t);
 extern bool_t	tosh_pause_resume(bool_t);
-extern bool_t	tosh_get_playstatus(curstat_t *, byte_t *);
+extern bool_t	tosh_get_playstatus(cdstat_t *);
 extern bool_t	tosh_get_toc(curstat_t *);
 extern bool_t	tosh_mute(bool_t);
 extern bool_t	tosh_eject(void);
