@@ -1,5 +1,5 @@
 /*
- * @(#)gobrowser.c	7.13 01/04/11
+ * @(#)gobrowser.c	7.16 02/04/22
  * 
  * Usage: gobrowser url_string
  *
@@ -63,6 +63,15 @@
 #include <X11/Xatom.h>
 
 
+#ifdef sony_news
+typedef int			pid_t;
+typedef int			mode_t;
+#define WAITPID(pid, svp, op)	wait4(pid, svp, 0, 0)
+#else
+#define WAITPID			waitpid
+#endif  /* sony_news */
+
+
 /* Executable names to match */
 char	*browser_names[] = {
 	"netscape",
@@ -73,9 +82,14 @@ char	*browser_names[] = {
 	"netscape-navigator",
 	"communicator",
 	"navigator",
+	"mozilla",
+	"Mozilla",
+	"mozilla-viewer.sh",
+	"run-mozilla.sh",
 	NULL
 };
 
+
 /* Directories to look for netscape executable
  * In addition to these, gobrowser will also walk the user's PATH
  * environment looking there too.
@@ -96,6 +110,10 @@ char	*search_paths[] = {
 	"/opt/netscape",
 	"/opt/communicator/bin",
 	"/opt/communicator",
+	"/usr/local/mozilla",
+	"/opt/mozilla/bin",
+	"/opt/mozilla",
+	"/usr/local/src/mozilla",
 	NULL
 };
 
@@ -167,7 +185,7 @@ run_cmd(char *cmd)
 
 	default:
 		/* Parent process: wait for child to exit */
-		while ((ret = waitpid(cpid, &stat_val, 0)) != cpid) {
+		while ((ret = WAITPID(cpid, &stat_val, 0)) != cpid) {
 			if (ret < 0 && errno != EINTR)
 				break;
 		}
@@ -968,9 +986,9 @@ main(int argc, char **argv)
 	if ((browser_path = locate_browser(argv[0])) == NULL) {
 		(void) fprintf(stderr, "%s Error: %s\n%s\n%s\n",
 		    argv[0],
-		    "Cannot locate Netscape Navigator/Communicator.",
+		    "Cannot locate Netscape or Mozilla.",
 		    "To fix: Set the BROWSER_PATH environment variable to the",
-		    "Netscape executable file path."
+		    "web browser executable file path."
 		);
 		free(cmd);
 		exit(1);
@@ -983,8 +1001,26 @@ main(int argc, char **argv)
 	free(cmd);
 
 #ifdef DO_POPUP
-	/* Pop up a dialog box */
-	popup_dialog("Starting web browser...\nPlease wait.", &argc, argv);
+	{
+		char	*cp;
+
+		cp = (char *) malloc(strlen(browser_path) + 80);
+		if (cp == NULL) {
+			(void) fprintf(stderr, "%s Error: Out of memory.\n",
+				       argv[0]);
+		}
+		else {
+			(void) sprintf(cp,
+			    "Starting web browser:\n( %s )\n\nPlease wait...",
+			    browser_path
+			);
+
+			/* Pop up a dialog box */
+			popup_dialog(cp, &argc, argv);
+
+			free(cp);
+		}
+	}
 #endif
 
 	exit(exit_stat);
