@@ -1,7 +1,7 @@
 /*
  *   xmcd - Motif(tm) CD Audio Player
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 #define __CALLBACK_H__
 
 #ifndef LINT
-static char *_callback_h_ident_ = "@(#)callback.h	6.7 01/04/09";
+static char *_callback_h_ident_ = "@(#)callback.h	6.9 02/01/06";
 #endif
 
 /* Macros */
@@ -72,6 +72,11 @@ static char *_callback_h_ident_ = "@(#)callback.h	6.7 01/04/09";
 		(XtCallbackProc) (func),				\
 		(XtPointer) (arg))
 
+#define register_singlesel_cb(w, func, arg)				\
+	XtAddCallback((w), XmNsingleSelectionCallback,			\
+		(XtCallbackProc) (func),				\
+		(XtPointer) (arg))
+
 #define register_browsel_cb(w, func, arg)				\
 	XtAddCallback((w), XmNbrowseSelectionCallback,			\
 		(XtCallbackProc) (func),				\
