@@ -1,7 +1,7 @@
 /*
  *   xmcd - Motif(tm) CD Audio Player
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 #define __CDFUNC_H__
 
 #ifndef LINT
-static char *_cdfunc_h_ident_ = "@(#)cdfunc.h	7.12 01/04/09";
+static char *_cdfunc_h_ident_ = "@(#)cdfunc.h	7.21 02/04/01";
 #endif
 
 
@@ -62,6 +62,7 @@ static char *_cdfunc_h_ident_ = "@(#)cdfunc.h	7.12 01/04/09";
 
 
 /* Public functions */
+extern void	fix_outfile_path(curstat_t *);
 extern byte_t	curtrk_type(curstat_t *);
 extern void	dpy_disc(curstat_t *);
 extern void	dpy_track(curstat_t *);
@@ -145,6 +146,12 @@ extern void	cd_options_popdown(Widget, XtPointer, XtPointer);
 extern void	cd_options_reset(Widget, XtPointer, XtPointer);
 extern void	cd_options_save(Widget, XtPointer, XtPointer);
 extern void	cd_options(Widget, XtPointer, XtPointer);
+extern void	cd_options_categsel(Widget, XtPointer, XtPointer);
+extern void	cd_jitter_corr(Widget, XtPointer, XtPointer);
+extern void	cd_file_per_trk(Widget, XtPointer, XtPointer);
+extern void	cd_filefmt_mode(Widget, XtPointer, XtPointer);
+extern void	cd_filepath_new(Widget, XtPointer, XtPointer);
+extern void	cd_pipeprog_new(Widget, XtPointer, XtPointer);
 extern void	cd_balance(Widget, XtPointer, XtPointer);
 extern void	cd_balance_center(Widget, XtPointer, XtPointer);
 extern void	cd_about(Widget, XtPointer, XtPointer);
@@ -157,6 +164,8 @@ extern void	cd_rmcallback(Widget, XtPointer, XtPointer);
 extern void	cd_shell_focus_chg(Widget, XtPointer, XtPointer);
 extern void	cd_exit(Widget, XtPointer, XtPointer);
 extern void	cd_tooltip_cancel(Widget, XtPointer, XtPointer);
+extern void	cd_unlink_play(Widget, XtPointer, XtPointer);
+extern void	cd_abort_play(Widget, XtPointer, XtPointer);
 extern void	cd_not_implemented(Widget, XtPointer, XtPointer);
 
 /* Event handlers */
