@@ -1,7 +1,7 @@
 /*
  *   xmcd - Motif(tm) CD Audio Player
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  *
  */
 #ifndef LINT
-static char *_command_c_ident_ = "@(#)command.c	7.16 01/04/09";
+static char *_command_c_ident_ = "@(#)command.c	7.27 02/04/24";
 #endif
 
 #include "common_d/appenv.h"
@@ -43,9 +43,9 @@ extern FILE		*errfp;
 #define QUIT_DELAY	1000
 
 /* Log file banner */
-#define RMTLOG_BANNER	\
-"# xmcd %s.%s Remote control log file\n# %s\n#\n\
-# YY/MM/DD HH:MM:SS host/dev/pid/display user@host/pid command\n#\n"
+#define RMTLOG_BANNER1	"# xmcd %s.%s Remote control log file\n# %s\n#\n"
+#define RMTLOG_BANNER2	"# YY/MM/DD HH:MM:SS host/dev/pid/display \
+user@host/pid command\n#\n"
 
 #ifdef __VMS
 /* VMS: the device and host names should be case-insensitive */
@@ -1267,6 +1267,409 @@ cmd_do_changer(Display *dpy, curstat_t *s, char *arg, bool_t prn_usage)
 }
 
 
+/*
+ * cmd_do_mode
+ *	Function to execute the "mode" request
+ *
+ * Args:
+ *	dpy - The X display.
+ *	s - Pointer to the curstat_t structure.
+ *	arg - Argument string.
+ *	prn_usage - if TRUE, display argument usage help.
+ *
+ * Return:
+ *	status code CMD_STAT_*
+ */
+/*ARGSUSED*/
+STATIC int
+cmd_do_mode(Display *dpy, curstat_t *s, char *arg, bool_t prn_usage)
+{
+	if (prn_usage) {
+		(void) fprintf(errfp, "\tmode %s\n",
+			"<standard | cdda-play | cdda-save | cdda-pipe>");
+		return CMD_STAT_SUCCESS;
+	}
+	if (strcmp(arg, "standard") == 0) {
+		XmToggleButtonSetState(
+			widgets.options.mode_std_btn,
+			True,
+			True
+		);
+		return CMD_STAT_SUCCESS;
+	}
+	else if (strcmp(arg, "cdda-play") == 0 &&
+		 XtIsSensitive(widgets.options.mode_cdda_btn)) {
+		XmToggleButtonSetState(
+			widgets.options.mode_cdda_btn,
+			!XmToggleButtonGetState(widgets.options.mode_cdda_btn),
+			True
+		);
+		return CMD_STAT_SUCCESS;
+	}
+	else if (strcmp(arg, "cdda-save") == 0 &&
+		 XtIsSensitive(widgets.options.mode_file_btn)) {
+		XmToggleButtonSetState(
+			widgets.options.mode_file_btn,
+			!XmToggleButtonGetState(widgets.options.mode_file_btn),
+			True
+		);
+		return CMD_STAT_SUCCESS;
+	}
+	else if (strcmp(arg, "cdda-pipe") == 0 &&
+		 XtIsSensitive(widgets.options.mode_pipe_btn)) {
+		XmToggleButtonSetState(
+			widgets.options.mode_pipe_btn,
+			!XmToggleButtonGetState(widgets.options.mode_pipe_btn),
+			True
+		);
+		return CMD_STAT_SUCCESS;
+	}
+	return CMD_STAT_BADARG;
+}
+
+
+/*
+ * cmd_do_jitter
+ *	Function to execute the "jittercorr" request
+ *
+ * Args:
+ *	dpy - The X display.
+ *	s - Pointer to the curstat_t structure.
+ *	arg - Argument string.
+ *	prn_usage - if TRUE, display argument usage help.
+ *
+ * Return:
+ *	status code CMD_STAT_*
+ */
+/*ARGSUSED*/
+STATIC int
+cmd_do_jitter(Display *dpy, curstat_t *s, char *arg, bool_t prn_usage)
+{
+	if (prn_usage) {
+		(void) fprintf(errfp, "\tjittercorr %s\n",
+			"<on | off>");
+		return CMD_STAT_SUCCESS;
+	}
+
+	if (!XtIsSensitive(widgets.options.mode_jitter_btn))
+		return CMD_STAT_INVAL;
+
+	if (strcmp(arg, "on") == 0) {
+		XmToggleButtonSetState(
+			widgets.options.mode_jitter_btn,
+			True,
+			True
+		);
+		return CMD_STAT_SUCCESS;
+	}
+	if (strcmp(arg, "off") == 0) {
+		XmToggleButtonSetState(
+			widgets.options.mode_jitter_btn,
+			False,
+			True
+		);
+		return CMD_STAT_SUCCESS;
+	}
+	return CMD_STAT_BADARG;
+}
+
+
+/*
+ * cmd_do_trkfile
+ *	Function to execute the "trackfile" request
+ *
+ * Args:
+ *	dpy - The X display.
+ *	s - Pointer to the curstat_t structure.
+ *	arg - Argument string.
+ *	prn_usage - if TRUE, display argument usage help.
+ *
+ * Return:
+ *	status code CMD_STAT_*
+ */
+/*ARGSUSED*/
+STATIC int
+cmd_do_trkfile(Display *dpy, curstat_t *s, char *arg, bool_t prn_usage)
+{
+	if (prn_usage) {
+		(void) fprintf(errfp, "\ttrackfile %s\n",
+			"<on | off>");
+		return CMD_STAT_SUCCESS;
+	}
+
+	if (!XtIsSensitive(widgets.options.mode_trkfile_btn))
+		return CMD_STAT_INVAL;
+
+	if (strcmp(arg, "on") == 0) {
+		XmToggleButtonSetState(
+			widgets.options.mode_trkfile_btn,
+			True,
+			True
+		);
+		return CMD_STAT_SUCCESS;
+	}
+	if (strcmp(arg, "off") == 0) {
+		XmToggleButtonSetState(
+			widgets.options.mode_trkfile_btn,
+			False,
+			True
+		);
+		return CMD_STAT_SUCCESS;
+	}
+	return CMD_STAT_BADARG;
+}
+
+
+/*
+ * cmd_do_filefmt
+ *	Function to execute the "filefmt" request
+ *
+ * Args:
+ *	dpy - The X display.
+ *	s - Pointer to the curstat_t structure.
+ *	arg - Argument string.
+ *	prn_usage - if TRUE, display argument usage help.
+ *
+ * Return:
+ *	status code CMD_STAT_*
+ */
+/*ARGSUSED*/
+STATIC int
+cmd_do_filefmt(Display *dpy, curstat_t *s, char *arg, bool_t prn_usage)
+{
+	Widget	menuw;
+
+	if (prn_usage) {
+		(void) fprintf(errfp, "\tfilefmt %s\n",
+			"<raw | au | wav | aiff | aiff-c>");
+		return CMD_STAT_SUCCESS;
+	}
+
+	if (!XtIsSensitive(widgets.options.mode_fmt_opt))
+		return CMD_STAT_INVAL;
+
+	if (strcmp(arg, "raw") == 0) {
+		menuw = widgets.options.mode_fmt_raw_btn;
+		app_data.cdda_filefmt = FILEFMT_RAW;
+	}
+	else if (strcmp(arg, "au") == 0) {
+		menuw = widgets.options.mode_fmt_au_btn;
+		app_data.cdda_filefmt = FILEFMT_AU;
+	}
+	else if (strcmp(arg, "wav") == 0) {
+		menuw = widgets.options.mode_fmt_wav_btn;
+		app_data.cdda_filefmt = FILEFMT_WAV;
+	}
+	else if (strcmp(arg, "aiff") == 0) {
+		menuw = widgets.options.mode_fmt_aiff_btn;
+		app_data.cdda_filefmt = FILEFMT_AIFF;
+	}
+	else if (strcmp(arg, "aiff-c") == 0) {
+		menuw = widgets.options.mode_fmt_aifc_btn;
+		app_data.cdda_filefmt = FILEFMT_AIFC;
+	}
+	else
+		return CMD_STAT_BADARG;
+
+	/* Fix output file suffix to match the file type */
+	fix_outfile_path(s);
+
+	XtVaSetValues(widgets.options.mode_fmt_opt,
+		XmNmenuHistory, menuw,
+		NULL
+	);
+
+	XmTextSetString(widgets.options.mode_path_txt, s->outf_tmpl);
+
+	return CMD_STAT_SUCCESS;
+}
+
+
+/*
+ * cmd_do_outfile
+ *	Function to execute the "outfile" request
+ *
+ * Args:
+ *	dpy - The X display.
+ *	s - Pointer to the curstat_t structure.
+ *	arg - Argument string.
+ *	prn_usage - if TRUE, display argument usage help.
+ *
+ * Return:
+ *	status code CMD_STAT_*
+ */
+/*ARGSUSED*/
+STATIC int
+cmd_do_outfile(Display *dpy, curstat_t *s, char *arg, bool_t prn_usage)
+{
+	char	*cp,
+		*cp2,
+		*cp3,
+		*suf;
+	int	newfmt;
+	Widget	menuw;
+
+	if (prn_usage) {
+		(void) fprintf(errfp, "\toutfile <template>\n");
+		return CMD_STAT_SUCCESS;
+	}
+
+	if (!XtIsSensitive(widgets.options.mode_path_txt))
+		return CMD_STAT_INVAL;
+
+	if (s->outf_tmpl != NULL && strcmp(arg, s->outf_tmpl) == 0)
+		/* Not changed */
+		return CMD_STAT_SUCCESS;
+
+	switch (app_data.cdda_filefmt) {
+	case FILEFMT_RAW:
+		suf = ".raw";
+		break;
+	case FILEFMT_AU:
+		suf = ".au";
+		break;
+	case FILEFMT_WAV:
+		suf = ".wav";
+		break;
+	case FILEFMT_AIFF:
+		suf = ".aiff";
+		break;
+	case FILEFMT_AIFC:
+		suf = ".aifc";
+		break;
+	default:
+		suf = "";
+		break;
+	}
+
+	/* Check if file suffix indicates a change in file format */
+	newfmt = app_data.cdda_filefmt;
+	menuw = (Widget) NULL;
+	cp = arg;
+	if ((cp2 = strrchr(cp, '.')) != NULL) {
+		if ((cp3 = strrchr(cp, DIR_END)) != NULL && cp2 > cp3) {
+			if (strcmp(suf, cp2) != 0) {
+				if (util_strcasecmp(cp2, ".raw") == 0) {
+				    newfmt = FILEFMT_RAW;
+				    menuw = widgets.options.mode_fmt_raw_btn;
+				}
+				else if (util_strcasecmp(cp2, ".au") == 0) {
+				    newfmt = FILEFMT_AU;
+				    menuw = widgets.options.mode_fmt_au_btn;
+				}
+				else if (util_strcasecmp(cp2, ".wav") == 0) {
+				    newfmt = FILEFMT_WAV;
+				    menuw = widgets.options.mode_fmt_wav_btn;
+				}
+				else if (util_strcasecmp(cp2, ".aiff") == 0) {
+				    newfmt = FILEFMT_AIFF;
+				    menuw = widgets.options.mode_fmt_aiff_btn;
+				}
+				else if (util_strcasecmp(cp2, ".aifc") == 0) {
+				    newfmt = FILEFMT_AIFC;
+				    menuw = widgets.options.mode_fmt_aifc_btn;
+				}
+			}
+		}
+		else if (strcmp(suf, cp2) != 0) {
+			if (util_strcasecmp(cp2, ".raw") == 0) {
+				newfmt = FILEFMT_RAW;
+				menuw = widgets.options.mode_fmt_raw_btn;
+			}
+			else if (util_strcasecmp(cp2, ".au") == 0) {
+				newfmt = FILEFMT_AU;
+				menuw = widgets.options.mode_fmt_au_btn;
+			}
+			else if (util_strcasecmp(cp2, ".wav") == 0) {
+				newfmt = FILEFMT_WAV;
+				menuw = widgets.options.mode_fmt_wav_btn;
+			}
+			else if (util_strcasecmp(cp2, ".aiff") == 0) {
+				newfmt = FILEFMT_AIFF;
+				menuw = widgets.options.mode_fmt_aiff_btn;
+			}
+			else if (util_strcasecmp(cp2, ".aifc") == 0) {
+				newfmt = FILEFMT_AIFC;
+				menuw = widgets.options.mode_fmt_aifc_btn;
+			}
+		}
+	}
+
+	if (!util_newstr(&s->outf_tmpl, cp))
+		return CMD_STAT_INVAL;
+
+	app_data.cdda_filefmt = newfmt;
+
+	/* Fix output file suffix to match the file type */
+	fix_outfile_path(s);
+
+	/* File format changed */
+	if (menuw != (Widget) NULL && newfmt != app_data.cdda_filefmt) {
+		XtVaSetValues(widgets.options.mode_fmt_opt,
+			XmNmenuHistory, menuw,
+			NULL
+		);
+	}
+
+	if (util_strstr(s->outf_tmpl, "%T") != NULL ||
+	    util_strstr(s->outf_tmpl, "%t") != NULL ||
+	    util_strstr(s->outf_tmpl, "%R") != NULL ||
+	    util_strstr(s->outf_tmpl, "%r") != NULL ||
+	    util_strstr(s->outf_tmpl, "%#") != NULL) {
+		if (!app_data.cdda_trkfile) {
+			XmToggleButtonSetState(
+				widgets.options.mode_trkfile_btn,
+				True,
+				False
+			);
+			app_data.cdda_trkfile = TRUE;
+		}
+	}
+	else if (app_data.cdda_trkfile) {
+		XmToggleButtonSetState(
+			widgets.options.mode_trkfile_btn,
+			False,
+			False
+		);
+		app_data.cdda_trkfile = FALSE;
+	}
+
+	XmTextSetString(widgets.options.mode_path_txt, s->outf_tmpl);
+
+	return CMD_STAT_SUCCESS;
+}
+
+
+/*
+ * cmd_do_pipeprog
+ *	Function to execute the "pipeprog" request
+ *
+ * Args:
+ *	dpy - The X display.
+ *	s - Pointer to the curstat_t structure.
+ *	arg - Argument string.
+ *	prn_usage - if TRUE, display argument usage help.
+ *
+ * Return:
+ *	status code CMD_STAT_*
+ */
+/*ARGSUSED*/
+STATIC int
+cmd_do_pipeprog(Display *dpy, curstat_t *s, char *arg, bool_t prn_usage)
+{
+	if (prn_usage) {
+		(void) fprintf(errfp, "\tpipeprog <path [arg ...]>\n");
+		return CMD_STAT_SUCCESS;
+	}
+
+	if (!XtIsSensitive(widgets.options.mode_prog_txt))
+		return CMD_STAT_INVAL;
+
+	XmTextSetString(widgets.options.mode_prog_txt, arg);
+	return CMD_STAT_SUCCESS;
+}
+
+
 /*
  * cmd_do_window
  *	Function to execute the "window" request
@@ -1377,6 +1780,8 @@ cmd_do_debug(Display *dpy, curstat_t *s, char *arg, bool_t prn_usage)
 	else
 		(void) fprintf(errfp, "Disabling DEBUG.\n");
 
+	/* Debug level change notification */
+	di_debug();
 	return CMD_STAT_SUCCESS;
 }
 
@@ -1407,6 +1812,12 @@ struct {
 	{ "on-done",	cmd_do_ondone,	TRUE	},
 	{ "on-eject",	cmd_do_oneject,	TRUE	},
 	{ "changer",	cmd_do_changer,	TRUE	},
+	{ "mode",	cmd_do_mode,	TRUE	},
+	{ "jittercorr",	cmd_do_jitter,	TRUE	},
+	{ "trackfile",	cmd_do_trkfile,	TRUE	},
+	{ "filefmt",	cmd_do_filefmt,	TRUE	},
+	{ "outfile",	cmd_do_outfile,	TRUE	},
+	{ "pipeprog",	cmd_do_pipeprog,TRUE	},
 	{ "window",	cmd_do_window,	TRUE	},
 	{ "quit",	cmd_do_quit,	FALSE	},
 	{ "debug",	cmd_do_debug,	TRUE	},
@@ -2118,7 +2529,7 @@ cmd_rmtlog(Display *dpy, char *attstr, char *reqstr)
 
 	if (newfile)
 		/* Write remote log file header */
-		(void) fprintf(fp, RMTLOG_BANNER,
+		(void) fprintf(fp, RMTLOG_BANNER1 RMTLOG_BANNER2,
 			       VERSION_MAJ, VERSION_MIN, COPYRIGHT);
 
 	(void) time(&t);
@@ -2204,7 +2615,7 @@ cmd_init(curstat_t *s, Display *dpy, bool_t sender)
 			/* No library directory specified */
 			if (di_isdemo()) {
 				/* Demo mode: just fake it */
-				app_data.libdir = ".";
+				app_data.libdir = CUR_DIR;
 			}
 			else {
 				/* Real application: this is a fatal error */
