@@ -1,7 +1,7 @@
 /*
  *   xmcd - Motif(tm) CD Audio Player
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 #define __COMMAND_H__
 
 #ifndef LINT
-static char *_command_h_ident_ = "@(#)command.h	6.9 01/04/09";
+static char *_command_h_ident_ = "@(#)command.h	6.11 02/01/06";
 #endif
 
 
@@ -41,6 +41,22 @@ static char *_command_h_ident_ = "@(#)command.h	6.9 01/04/09";
 
 /* Status codes */
 #define CMD_STAT_SUCCESS	0	/* Request completed successfully */
+#ifdef __VMS
+/* VMS program exit codes must map to certain system-defined values
+ * otherwise we would get inappropriate error messages.
+ */
+#define CMD_STAT_NOCLIENT	2312	/* No remote client window found */
+#define CMD_STAT_ATTFAIL	231616	/* Cannot attach to remote window */
+#define CMD_STAT_PROCESSING	4976	/* Client is processing request */
+#define CMD_STAT_DESTROYED	1704	/* Remote window was destroyed */
+#define CMD_STAT_ACKFAIL	2642	/* Request acknowledgement error */
+#define CMD_STAT_UNSUPP		9224	/* Unsupported request */
+#define CMD_STAT_BADARG		4040	/* Invalid argument */
+#define CMD_STAT_INVAL		229976	/* Invalid operation */
+#define CMD_STAT_DISABLED	848	/* Remote control is disabled */
+#define CMD_STAT_NOCMD		229992	/* No command specified */
+#else
+/* UNIX */
 #define CMD_STAT_NOCLIENT	61	/* No remote client window found */
 #define CMD_STAT_ATTFAIL	62	/* Cannot attach to remote window */
 #define CMD_STAT_PROCESSING	63	/* Client is processing request */
@@ -51,6 +67,7 @@ static char *_command_h_ident_ = "@(#)command.h	6.9 01/04/09";
 #define CMD_STAT_INVAL		68	/* Invalid operation */
 #define CMD_STAT_DISABLED	69	/* Remote control is disabled */
 #define CMD_STAT_NOCMD		70	/* No command specified */
+#endif
 
 #ifdef __VMS
 #define RL_RET(code) 		return
