@@ -1,7 +1,7 @@
 /*
  *   xmcd - Motif CD Player
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 #define __GEOM_H__
 
 #ifndef LINT
-static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
+static char *_geom_h_ident_ = "@(#)geom.h	7.53 02/03/26";
 #endif
 
 /* Location of widgets relative to form origin, express in percentage of
@@ -195,6 +195,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 #define TOP_FF			84
 #define BOTTOM_FF		100
 
+
 /* Main window widgets: basic mode */
 #define LEFT_BMODE		0
 #define RIGHT_BMODE		17
@@ -245,6 +246,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 #define TOP_BNEXTTRK		66
 #define BOTTOM_BNEXTTRK		100
 
+
 /* Keypad window widgets */
 #define LEFT_KEYPADLBL		5
 #define RIGHT_KEYPADLBL		95
@@ -339,121 +341,158 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 #define RIGHT_KPCANCEL		70
 #define TOP_KPCANCEL		88
 
+
 /* Options window widgets */
-#define LEFT_LOAD_LBL		6
-#define RIGHT_LOAD_LBL		47
-#define TOP_LOAD_LBL		1
-#define BOTTOM_LOAD_LBL		5
+#define LEFT_RESET_BTN		8
+#define RIGHT_RESET_BTN		28
+#define BOFF_RESET_BTN		10
 
-#define LEFT_LOAD_CHKFRM	6
-#define RIGHT_LOAD_CHKFRM	47
-#define TOP_LOAD_CHKFRM		5
+#define LEFT_SAVE_BTN		40
+#define RIGHT_SAVE_BTN		60
+#define BOFF_SAVE_BTN		10
 
-#define LEFT_LOAD_RADFRM	6
-#define RIGHT_LOAD_RADFRM	47
-#define TOP_LOAD_RADFRM		11
-#define BOTTOM_LOAD_RADFRM	26
-
-#define LEFT_EXIT_LBL		6
-#define RIGHT_EXIT_LBL		47
-#define TOP_EXIT_LBL		26
-#define BOTTOM_EXIT_LBL		30
-
-#define LEFT_EXIT_RADFRM	6
-#define RIGHT_EXIT_RADFRM	47
-#define TOP_EXIT_RADFRM		30
-#define BOTTOM_EXIT_RADFRM	45
-
-#define LEFT_DONE_LBL		6
-#define RIGHT_DONE_LBL		47
-#define TOP_DONE_LBL		45
-#define BOTTOM_DONE_LBL		49
-
-#define LEFT_DONE_CHKFRM	6
-#define RIGHT_DONE_CHKFRM	47
-#define TOP_DONE_CHKFRM		49
-#define BOTTOM_DONE_CHKFRM	60
-
-#define LEFT_EJECT_LBL		6
-#define RIGHT_EJECT_LBL		47
-#define TOP_EJECT_LBL		60
-#define BOTTOM_EJECT_LBL	64
-
-#define LEFT_EJECT_CHKFRM	6
-#define RIGHT_EJECT_CHKFRM	47
-#define TOP_EJECT_CHKFRM	64
-#define BOTTOM_EJECT_CHKFRM	70
-
-#define LEFT_CHG_LBL		53
-#define RIGHT_CHG_LBL		94
-#define TOP_CHG_LBL		1
-#define BOTTOM_CHG_LBL		5
-
-#define LEFT_CHG_CHKFRM		53
-#define RIGHT_CHG_CHKFRM	94
-#define TOP_CHG_CHKFRM		5
-#define BOTTOM_CHG_CHKFRM	16
-
-#define LEFT_CHROUTE_LBL	53
-#define RIGHT_CHROUTE_LBL	94
-#define TOP_CHROUTE_LBL		20
-#define BOTTOM_CHROUTE_LBL	24
-
-#define LEFT_CHROUTE_RADFRM	53
-#define RIGHT_CHROUTE_RADFRM	94
-#define TOP_CHROUTE_RADFRM	24
-#define BOTTOM_CHROUTE_RADFRM	47
-
-#define LEFT_VOLTP_LBL		53
-#define RIGHT_VOLTP_LBL		94
-#define TOP_VOLTP_LBL		51
-#define BOTTOM_VOLTP_LBL	55
-
-#define LEFT_VOLTP_RADFRM	53
-#define RIGHT_VOLTP_RADFRM	94
-#define TOP_VOLTP_RADFRM	55
-#define BOTTOM_VOLTP_RADFRM	70
-
-#define LEFT_BAL_LBL		20
-#define RIGHT_BAL_LBL		80
-#define TOP_BAL_LBL		71
-#define BOTTOM_BAL_LBL		75
-
-#define LEFT_BALL_LBL		5
-#define RIGHT_BALL_LBL		20
-#define TOP_BALL_LBL		75
-#define BOTTOM_BALL_LBL		79
-
-#define LEFT_BALR_LBL		80
-#define RIGHT_BALR_LBL		95
-#define TOP_BALR_LBL		75
-#define BOTTOM_BALR_LBL		79
-
-#define LEFT_BAL_SCALE		20
-#define RIGHT_BAL_SCALE		80
-#define TOP_BAL_SCALE		75
-#define BOTTOM_BAL_SCALE	79
-
-#define LEFT_BALCTR_BTN		35
-#define RIGHT_BALCTR_BTN	65
-#define TOP_BALCTR_BTN		80
-#define BOTTOM_BALCTR_BTN	86
+#define LEFT_OPTOK_BTN		72
+#define RIGHT_OPTOK_BTN		92
+#define BOFF_OPTOK_BTN		10
 
 #define LEFT_OPTSEP		0
 #define RIGHT_OPTSEP		100
-#define TOP_OPTSEP		88
+#define BOFF_OPTSEP		10
 
-#define LEFT_RESET_BTN		4
-#define RIGHT_RESET_BTN		32
-#define TOP_RESET_BTN		91
+#define LEFT_CATEG_LBL		3
+#define RIGHT_CATEG_LBL		34
+#define TOFF_CATEG_LBL		3
 
-#define LEFT_SAVE_BTN		36
-#define RIGHT_SAVE_BTN		64
-#define TOP_SAVE_BTN		91
+#define LEFT_CATEG_LIST		3
+#define RIGHT_CATEG_LIST	34
+#define TOFF_CATEG_LIST		2
+#define BOFF_CATEG_LIST		8
+
+#define LOFF_CATEG_SEP		10
+
+#define LEFT_MODE_LBL		40
+#define RIGHT_MODE_LBL		96
+#define TOFF_MODE_LBL		4
+
+#define LEFT_MODE_CHKFRM	40
+#define RIGHT_MODE_CHKFRM	96
+#define TOFF_MODE_CHKFRM	0
+#define BOTTOM_MODE_CHKFRM	37
+
+#define LEFT_JITTER_BTN		40
+#define RIGHT_JITTER_BTN	68
+#define TOFF_JITTER_BTN		6
+
+#define LEFT_TRKFILE_BTN	68
+#define RIGHT_TRKFILE_BTN	96
+#define TOFF_TRKFILE_BTN	6
+
+#define LEFT_MODEFMT_OPT	40
+#define RIGHT_MODEFMT_OPT	96
+#define TOFF_MODEFMT_OPT	3
+
+#define LEFT_PATH_LBL		40
+#define RIGHT_PATH_LBL		97
+#define TOFF_PATH_LBL		3
+
+#define LEFT_PATH_TXT		40
+#define RIGHT_PATH_TXT		97
+#define TOFF_PATH_TXT		0
+
+#define LEFT_PROG_LBL		40
+#define RIGHT_PROG_LBL		97
+#define TOFF_PROG_LBL		3
+
+#define LEFT_PROG_TXT		40
+#define RIGHT_PROG_TXT		97
+#define TOFF_PROG_TXT		0
+
+#define LEFT_LOAD_LBL		40
+#define RIGHT_LOAD_LBL		67
+#define TOFF_LOAD_LBL		6
+
+#define LEFT_LOAD_CHKFRM	40
+#define RIGHT_LOAD_CHKFRM	67
+#define TOFF_LOAD_CHKFRM	1
+#define BOTTOM_LOAD_CHKFRM	16
+
+#define LEFT_LOAD_RADFRM	40
+#define RIGHT_LOAD_RADFRM	67
+#define TOFF_LOAD_RADFRM	1
+#define BOTTOM_LOAD_RADFRM	36
+
+#define LEFT_EJECT_LBL		40
+#define RIGHT_EJECT_LBL		67
+#define TOFF_EJECT_LBL		6
+
+#define LEFT_EJECT_CHKFRM	40
+#define RIGHT_EJECT_CHKFRM	67
+#define TOFF_EJECT_CHKFRM	1
+#define BOTTOM_EJECT_CHKFRM	52
+
+#define LEFT_DONE_LBL		69
+#define RIGHT_DONE_LBL		96
+#define TOFF_DONE_LBL		6
+
+#define LEFT_DONE_CHKFRM	69
+#define RIGHT_DONE_CHKFRM	96
+#define TOFF_DONE_CHKFRM	1
+#define BOTTOM_DONE_CHKFRM	21
+
+#define LEFT_EXIT_LBL		69
+#define RIGHT_EXIT_LBL		96
+#define TOFF_EXIT_LBL		20
+
+#define LEFT_EXIT_RADFRM	69
+#define RIGHT_EXIT_RADFRM	96
+#define TOFF_EXIT_RADFRM	1
+#define BOTTOM_EXIT_RADFRM	52
+
+#define LEFT_CHG_LBL		50
+#define RIGHT_CHG_LBL		86
+#define TOFF_CHG_LBL		6
+
+#define LEFT_CHG_CHKFRM		50
+#define RIGHT_CHG_CHKFRM	86
+#define TOFF_CHG_CHKFRM		3
+#define BOTTOM_CHG_CHKFRM	22
+
+#define LEFT_CHROUTE_LBL	50
+#define RIGHT_CHROUTE_LBL	86
+#define TOFF_CHROUTE_LBL	6
+
+#define LEFT_CHROUTE_RADFRM	50
+#define RIGHT_CHROUTE_RADFRM	86
+#define TOFF_CHROUTE_RADFRM	3
+#define BOTTOM_CHROUTE_RADFRM	38
+
+#define LEFT_VOLTP_LBL		50
+#define RIGHT_VOLTP_LBL		84
+#define TOFF_VOLTP_LBL		6
+
+#define LEFT_VOLTP_RADFRM	50
+#define RIGHT_VOLTP_RADFRM	86
+#define TOFF_VOLTP_RADFRM	3
+#define BOTTOM_VOLTP_RADFRM	27
+
+#define LEFT_BAL_LBL		40
+#define RIGHT_BAL_LBL		96
+#define TOFF_BAL_LBL		8
+
+#define LEFT_BALL_LBL		40
+#define RIGHT_BALL_LBL		50
+
+#define LEFT_BALR_LBL		86
+#define RIGHT_BALR_LBL		96
+
+#define LEFT_BAL_SCALE		50
+#define RIGHT_BAL_SCALE		86
+#define TOFF_BAL_SCALE		3
+
+#define LEFT_BALCTR_BTN		58
+#define RIGHT_BALCTR_BTN	78
+#define TOFF_BALCTR_BTN		3
 
-#define LEFT_OPTOK_BTN		68
-#define RIGHT_OPTOK_BTN		96
-#define TOP_OPTOK_BTN		91
 
 /* CD Information/Program window widgets */
 #define LEFT_TOTTIMEIND		2
@@ -529,9 +568,12 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 #define BOFF_TTITLELBL		0
 
 #define LEFT_TTITLE		2
-#define RIGHT_TTITLE		79
+#define RIGHT_TTITLE		65
 #define BOFF_TTITLE		2
 
+#define LOFF_APPLYBTN		0
+#define RIGHT_APPLYBTN		79
+
 #define LEFT_EXTTLBL		81
 #define RIGHT_EXTTLBL		98
 #define TOFF_EXTTLBL		4
@@ -587,6 +629,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 #define RIGHT_DPOK		94
 #define BOFF_DPOK		14
 
+
 /* Disc List window widgets */
 #define LEFT_DLISTOPT		2
 #define TOFF_DLISTOPT		8
@@ -629,6 +672,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 #define TOFF_DISCLIST		2
 #define BOFF_DISCLIST		8
 
+
 /* Full name editor window widgets */
 #define LEFT_DAHEADLBL		2
 #define RIGHT_DAHEADLBL		98
@@ -674,6 +718,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 #define RIGHT_DASEP		100
 #define BOFF_DASEP		12
 
+
 /* Disc details window widgets */
 #define LEFT_DDDISCNUM		40
 #define RIGHT_DDDISCNUM		60
@@ -720,6 +765,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 
 #define LEFT_DDSUBGENRE0OPT	41
 #define LOFF_DDSUBGENRE0OPT	6
+#define ROFF_DDSUBGENRE0OPT	6
 #define TOFF_DDSUBGENRE0OPT	6
 
 #define LEFT_DDGENRE1OPT	1
@@ -728,6 +774,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 
 #define LEFT_DDSUBGENRE1OPT	41
 #define LOFF_DDSUBGENRE1OPT	6
+#define ROFF_DDSUBGENRE1OPT	6
 #define TOFF_DDSUBGENRE1OPT	2
 
 #define ROFF_DDDNUMLBL		4
@@ -770,7 +817,6 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 
 #define LEFT_DDCERTIND		35
 #define RIGHT_DDCERTIND		94
-#define BOFF_DDCERTIND		4
 
 #define LEFT_DDREVLBL		6
 #define RIGHT_DDREVLBL		34
@@ -778,7 +824,6 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 
 #define LEFT_DDREVIND		35
 #define RIGHT_DDREVIND		94
-#define BOFF_DDREVIND		0
 
 #define LEFT_DDDISCIDLBL	6
 #define RIGHT_DDDISCIDLBL	34
@@ -786,7 +831,6 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 
 #define LEFT_DDDISCIDIND	35
 #define RIGHT_DDDISCIDIND	94
-#define BOFF_DDDISCIDIND	0
 
 #define LEFT_DDNOTESTXT		2
 #define RIGHT_DDNOTESTXT	98
@@ -860,6 +904,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 
 #define LEFT_DTSUBGENRE0OPT	41
 #define LOFF_DTSUBGENRE0OPT	6
+#define ROFF_DTSUBGENRE0OPT	6
 #define TOFF_DTSUBGENRE0OPT	6
 
 #define LEFT_DTGENRE1OPT	1
@@ -868,6 +913,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 
 #define LEFT_DTSUBGENRE1OPT	41
 #define LOFF_DTSUBGENRE1OPT	6
+#define ROFF_DTSUBGENRE1OPT	6
 #define TOFF_DTSUBGENRE1OPT	2
 
 #define LEFT_DTSEP2		0
@@ -898,6 +944,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 #define RIGHT_DTNOTESTXT	98
 #define BOFF_DTNOTESTXT		4
 
+
 /* Credits window widgets */
 #define LEFT_CRAUTOTRKBTN	2
 #define TOFF_CRAUTOTRKBTN	4
@@ -939,6 +986,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 
 #define LEFT_CRSUBROLEOPT	45
 #define LOFF_CRSUBROLEOPT	6
+#define ROFF_CRSUBROLEOPT	6
 #define TOFF_CRSUBROLEOPT	6
 
 #define ROFF_CRNAMELBL		4
@@ -976,6 +1024,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 #define RIGHT_CROK		94
 #define BOFF_CROK		12
 
+
 /* Segments window widgets */
 #define LEFT_SGDISCNOLBL	40
 #define RIGHT_SGDISCNOLBL	60
@@ -1094,6 +1143,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 #define RIGHT_SGOK		94
 #define BOFF_SGOK		12
 
+
 /* SubmitURL window widgets */
 #define LOFF_SULOGO		10
 #define ROFF_SULOGO		10
@@ -1142,6 +1192,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 #define RIGHT_SUSEP		100
 #define BOFF_SUSEP		12
 
+
 /* Region selector popup widgets */
 #define LEFT_REGIONSELLBL	4
 #define RIGHT_REGIONSELLBL	96
@@ -1160,6 +1211,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 #define RIGHT_REGIONOK		65
 #define BOFF_REGIONOK		12
 
+
 /* Match selector popup widgets */
 #define LOFF_MATCHSELLOGO	10
 #define ROFF_MATCHSELLOGO	10
@@ -1182,7 +1234,8 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 #define RIGHT_MATCHOK		60
 #define BOFF_MATCHOK		12
 
-/* userreg widgets */
+
+/* Userreg widgets */
 #define LOFF_URLOGO		10
 #define ROFF_URLOGO		10
 #define TOFF_URLOGO		8
@@ -1279,6 +1332,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 #define RIGHT_URCANCELBTN	90
 #define BOFF_URCANCELBTN	12
 
+
 /* Help popup widgets */
 #define LEFT_TOPIC		2
 #define TOFF_TOPIC		6
@@ -1300,6 +1354,7 @@ static char *_geom_h_ident_ = "@(#)geom.h	7.44 01/07/18";
 #define RIGHT_HELPCANCEL	85
 #define BOFF_HELPCANCEL		12
 
+
 /* Authorization popup widgets */
 #define LEFT_AUTHLBL		5
 #define RIGHT_AUTHLBL		95
