@@ -1,7 +1,7 @@
 /*
  *   xmcd - Motif(tm) CD Audio Player
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  *
  */
 #ifndef LINT
-static char *_main_c_ident_ = "@(#)main.c	7.8 01/06/10";
+static char *_main_c_ident_ = "@(#)main.c	7.10 02/04/09";
 #endif
 
 #include "common_d/appenv.h"
@@ -179,6 +179,9 @@ main(int argc, char **argv)
 
 	/* Initialize variables */
 	progname = argv[0];
+	cmd = NULL;
+	localcmap = (Colormap) 0;
+	(void) memset(&status, 0, sizeof(curstat_t));
 
 	/* Handle some signals */
 	if (signal(SIGINT, onsig) == SIG_IGN)
