@@ -1,7 +1,7 @@
 /*
  *   xmcd - Motif(tm) CD Audio Player
  *
- *   Copyright (C) 1993-2001  Ti Kan
+ *   Copyright (C) 1993-2002  Ti Kan
  *   E-mail: xmcd@amb.org
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 #define __WIDGET_H__
 
 #ifndef LINT
-static char *_widget_h_ident_ = "@(#)widget.h	7.35 01/07/02";
+static char *_widget_h_ident_ = "@(#)widget.h	7.43 02/03/28";
 #endif
 
 /* Holder for all widgets */
@@ -95,6 +95,35 @@ typedef struct {
 	/* Options window widgets */
 	struct {
 		Widget	form;			/* Form container */
+
+		Widget	categ_lbl;		/* Category label */
+		Widget	categ_list;		/* Category list */
+		Widget	categ_sep;		/* Category separator */
+
+		Widget	mode_lbl;		/* Play mode label */
+		Widget	mode_chkbox_frm;	/* Play mode chkbox frame */
+		Widget	mode_chkbox;		/* Play mode check box */
+		Widget	mode_std_btn;		/* Standard button */
+		Widget	mode_cdda_btn;		/* CDDA button */
+		Widget	mode_file_btn;		/* Save file button */
+		Widget	mode_pipe_btn;		/* Pipe to program button */
+		Widget	mode_jitter_btn;	/* CDDA jitter corr button */
+		Widget	mode_trkfile_btn;	/* One file per track button */
+		Widget	mode_fmt_opt;		/* File format options menu */
+		Widget	mode_path_lbl;		/* File path label */
+		Widget	mode_path_txt;		/* File path ind text */
+		Widget	mode_prog_lbl;		/* Program path label */
+		Widget	mode_prog_txt;		/* Program path ind text */
+		Widget	mode_nullmarker;
+		Widget	mode_fmt_menu_lbl;	/* File format menu label */
+		Widget	mode_fmt_menu_sep;	/* File format menu sep */
+		Widget	mode_fmt_raw_btn;	/* CDR format button */
+		Widget	mode_fmt_au_btn;	/* AU format button */
+		Widget	mode_fmt_wav_btn;	/* WAV format button */
+		Widget	mode_fmt_aiff_btn;	/* AIFF format button */
+		Widget	mode_fmt_aifc_btn;	/* AIFF-C format button */
+		Widget	mode_fmt_menu;		/* File format pulldown menu */
+
 		Widget	load_lbl;		/* Load options label */
 		Widget	load_chkbox_frm;	/* Load options chkbox frame */
 		Widget	load_chkbox;		/* Load options check box */
@@ -119,19 +148,25 @@ typedef struct {
 		Widget	eject_chkbox_frm;	/* Eject options frame */
 		Widget	eject_chkbox;		/* Eject options check box */
 		Widget	eject_exit_btn;		/* Auto Exit button */
+		Widget	automation_nullmarker;
+
 		Widget	chg_lbl;		/* Changer options label */
 		Widget	chg_chkbox_frm;		/* Changer options frame */
 		Widget	chg_chkbox;		/* Changer options chk box */
 		Widget	chg_multiplay_btn;	/* Changer multi-play button */
 		Widget	chg_reverse_btn;	/* Changer reverse button */
-		Widget	chroute_lbl;		/* Mode select label */
-		Widget	chroute_radbox_frm;	/* Mode select frame */
-		Widget	chroute_radbox;		/* Mode select radio box */
+		Widget	changer_nullmarker;
+
+		Widget	chroute_lbl;		/* Channel route label */
+		Widget	chroute_radbox_frm;	/* Channel route frame */
+		Widget	chroute_radbox;		/* Channel route radio box */
 		Widget	chroute_stereo_btn;	/* Stereo button */
 		Widget	chroute_rev_btn;	/* Stereo Reverse button */
 		Widget	chroute_left_btn;	/* Mono Left-only button */
 		Widget	chroute_right_btn;	/* Mono Right-only button */
 		Widget	chroute_mono_btn;	/* Mono Left+Right button */
+		Widget	chroute_nullmarker;
+
 		Widget	vol_lbl;		/* Vol ctrl taper label */
 		Widget	vol_radbox_frm;		/* Vol ctrl taper frame */
 		Widget	vol_radbox;		/* Vol ctrl taper radio box */
@@ -143,6 +178,8 @@ typedef struct {
 		Widget	balr_lbl;		/* Balance ctrl right label */
 		Widget	bal_scale;		/* Balance ctrl scale */
 		Widget	balctr_btn;		/* Balance center button */
+		Widget	volbal_nulmarker;
+
 		Widget	options_sep;		/* Separator bar */
 		Widget	reset_btn;		/* Reset button */
 		Widget	save_btn;		/* Save button */
@@ -176,6 +213,7 @@ typedef struct {
 		Widget	trktime_btn;		/* Track time button */
 		Widget	ttitle_lbl;		/* Track title label */
 		Widget	ttitle_txt;		/* Track title text */
+		Widget	apply_btn;		/* Track title apply button */
 		Widget	extt_lbl;		/* Track label */
 		Widget	extt_btn;		/* Track details button */
 		Widget	tcredits_btn;		/* Track credits button */
